@@ -40,7 +40,6 @@
 #ifdef WIN32
 #undef SOCKET
 #include <winsock2.h>
-/* make sure to use the WSA error codes instead of the POSIX ones defined in errno.h */
 #ifdef EWOULDBLOCK
 #undef EWOULDBLOCK
 #endif
@@ -179,7 +178,7 @@ ReadFromRFBServer(rfbClient* client, char *out, unsigned int n)
       if (i <= 0) {
 	if (i < 0) {
 	  if (errno == EWOULDBLOCK || errno == EAGAIN) {
-	    if (++retries > 1000)
+	    if (++retries > 500)
 	    {
 		rfbClientLog("Connection timed out\n");
 		return FALSE;
@@ -227,7 +226,7 @@ ReadFromRFBServer(rfbClient* client, char *out, unsigned int n)
 	  errno=WSAGetLastError();
 #endif
 	  if (errno == EWOULDBLOCK || errno == EAGAIN) {
-	    if (++retries > 1000)
+	    if (++retries > 500)
 	    {
 		rfbClientLog("Connection timed out\n");
 		return FALSE;
@@ -271,7 +270,7 @@ hexdump:
  */
 
 rfbBool
-WriteToRFBServer(rfbClient* client, char *buf, int n)
+WriteToRFBServer(rfbClient* client, char *buf, unsigned int n)
 {
   fd_set fds;
   int i = 0;
@@ -362,10 +361,10 @@ static int initSockets() {
  * ConnectToTcpAddr connects to the given TCP port.
  */
 
-int
+SOCKET
 ConnectClientToTcpAddr(unsigned int host, int port)
 {
-  int sock;
+  SOCKET sock;
   struct sockaddr_in addr;
   int one = 1;
 #ifdef WIN32
@@ -375,19 +374,19 @@ ConnectClientToTcpAddr(unsigned int host, int port)
 #endif
 
   if (!initSockets())
-	  return -1;
+	  return INVALID_SOCKET;
 
   addr.sin_family = AF_INET;
   addr.sin_port = htons(port);
   addr.sin_addr.s_addr = host;
 
   sock = socket(AF_INET, SOCK_STREAM, 0);
-  if (sock < 0) {
+  if (sock == INVALID_SOCKET) {
 #ifdef WIN32
     errno=WSAGetLastError();
 #endif
     rfbClientErr("ConnectToTcpAddr: socket (%s)\n",strerror(errno));
-    return -1;
+    return INVALID_SOCKET;
   }
 
 #ifdef WIN32
@@ -400,26 +399,26 @@ ConnectClientToTcpAddr(unsigned int host, int port)
 #endif
 
   if (connect(sock, (struct sockaddr *)&addr, sizeof(addr)) < 0) {
-    /*rfbClientErr("ConnectToTcpAddr: connect\n");*/
+    rfbClientErr("ConnectToTcpAddr: connect\n");
     close(sock);
-    return -1;
+    return INVALID_SOCKET;
   }
 
   if (setsockopt(sock, IPPROTO_TCP, TCP_NODELAY,
 		 (char *)&one, sizeof(one)) < 0) {
     rfbClientErr("ConnectToTcpAddr: setsockopt\n");
     close(sock);
-    return -1;
+    return INVALID_SOCKET;
   }
 
   return sock;
 }
 
-int
+SOCKET
 ConnectClientToTcpAddr6(const char *hostname, int port)
 {
 #ifdef LIBVNCSERVER_IPv6
-  int sock;
+  SOCKET sock;
   int n;
   struct addrinfo hints, *res, *ressave;
   char port_s[10];
@@ -431,7 +430,7 @@ ConnectClientToTcpAddr6(const char *hostname, int port)
 #endif
 
   if (!initSockets())
-	  return -1;
+	  return INVALID_SOCKET;
 
   snprintf(port_s, 10, "%d", port);
   memset(&hints, 0, sizeof(struct addrinfo));
@@ -440,15 +439,15 @@ ConnectClientToTcpAddr6(const char *hostname, int port)
   if ((n = getaddrinfo(hostname, port_s, &hints, &res)))
   {
     rfbClientErr("ConnectClientToTcpAddr6: getaddrinfo (%s)\n", gai_strerror(n));
-    return -1;
+    return INVALID_SOCKET;
   }
 
   ressave = res;
-  sock = -1;
+  sock = INVALID_SOCKET;
   while (res)
   {
     sock = socket(res->ai_family, res->ai_socktype, res->ai_protocol);
-    if (sock >= 0)
+    if (sock != INVALID_SOCKET)
     {
 #ifdef WIN32
       timeout = 10000;
@@ -461,23 +460,25 @@ ConnectClientToTcpAddr6(const char *hostname, int port)
       if (connect(sock, res->ai_addr, res->ai_addrlen) == 0)
         break;
       close(sock);
-      sock = -1;
+      sock = INVALID_SOCKET;
     }
     res = res->ai_next;
   }
   freeaddrinfo(ressave);
 
-  if (sock == -1)
+  if (sock == INVALID_SOCKET)
   {
-    /*rfbClientErr("ConnectClientToTcpAddr6: connect\n");*/
-    return -1;
+#if 0
+    rfbClientErr("ConnectClientToTcpAddr6: connect\n");
+#endif
+    return INVALID_SOCKET;
   }
 
   if (setsockopt(sock, IPPROTO_TCP, TCP_NODELAY,
 		 (char *)&one, sizeof(one)) < 0) {
     rfbClientErr("ConnectToTcpAddr: setsockopt\n");
     close(sock);
-    return -1;
+    return INVALID_SOCKET;
   }
 
   return sock;
@@ -485,33 +486,37 @@ ConnectClientToTcpAddr6(const char *hostname, int port)
 #else
 
   rfbClientErr("ConnectClientToTcpAddr6: IPv6 disabled\n");
-  return -1;
+  return INVALID_SOCKET;
 
 #endif
 }
 
-int
+SOCKET
 ConnectClientToUnixSock(const char *sockFile)
 {
 #ifdef WIN32
   rfbClientErr("Windows doesn't support UNIX sockets\n");
-  return -1;
+  return INVALID_SOCKET;
 #else
-  int sock;
+  SOCKET sock;
   struct sockaddr_un addr;
   addr.sun_family = AF_UNIX;
+  if(strlen(sockFile) + 1 > sizeof(addr.sun_path)) {
+      rfbClientErr("ConnectToUnixSock: socket file name too long\n");
+      return -1;
+  }
   strcpy(addr.sun_path, sockFile);
 
   sock = socket(AF_UNIX, SOCK_STREAM, 0);
-  if (sock < 0) {
+  if (sock == INVALID_SOCKET) {
     rfbClientErr("ConnectToUnixSock: socket (%s)\n",strerror(errno));
-    return -1;
+    return INVALID_SOCKET;
   }
 
   if (connect(sock, (struct sockaddr *)&addr, sizeof(addr.sun_family) + strlen(addr.sun_path)) < 0) {
     rfbClientErr("ConnectToUnixSock: connect\n");
     close(sock);
-    return -1;
+    return INVALID_SOCKET;
   }
 
   return sock;
@@ -528,7 +533,8 @@ ConnectClientToUnixSock(const char *sockFile)
 int
 FindFreeTcpPort(void)
 {
-  int sock, port;
+  SOCKET sock;
+  int port;
   struct sockaddr_in addr;
 
   addr.sin_family = AF_INET;
@@ -538,7 +544,7 @@ FindFreeTcpPort(void)
     return -1;
 
   sock = socket(AF_INET, SOCK_STREAM, 0);
-  if (sock < 0) {
+  if (sock == INVALID_SOCKET) {
     rfbClientErr(": FindFreeTcpPort: socket\n");
     return 0;
   }
@@ -560,7 +566,7 @@ FindFreeTcpPort(void)
  * ListenAtTcpPort starts listening at the given TCP port.
  */
 
-int
+SOCKET
 ListenAtTcpPort(int port)
 {
   return ListenAtTcpPortAndAddress(port, NULL);
@@ -573,10 +579,10 @@ ListenAtTcpPort(int port)
  * the given IP address
  */
 
-int
+SOCKET
 ListenAtTcpPortAndAddress(int port, const char *address)
 {
-  int sock;
+  SOCKET sock = INVALID_SOCKET;
   int one = 1;
 #ifndef LIBVNCSERVER_IPv6
   struct sockaddr_in addr;
@@ -590,25 +596,25 @@ ListenAtTcpPortAndAddress(int port, const char *address)
   }
 
   if (!initSockets())
-    return -1;
+    return INVALID_SOCKET;
 
   sock = socket(AF_INET, SOCK_STREAM, 0);
-  if (sock < 0) {
+  if (sock == INVALID_SOCKET) {
     rfbClientErr("ListenAtTcpPort: socket\n");
-    return -1;
+    return INVALID_SOCKET;
   }
 
   if (setsockopt(sock, SOL_SOCKET, SO_REUSEADDR,
 		 (const char *)&one, sizeof(one)) < 0) {
     rfbClientErr("ListenAtTcpPort: setsockopt\n");
     close(sock);
-    return -1;
+    return INVALID_SOCKET;
   }
 
   if (bind(sock, (struct sockaddr *)&addr, sizeof(addr)) < 0) {
     rfbClientErr("ListenAtTcpPort: bind\n");
     close(sock);
-    return -1;
+    return INVALID_SOCKET;
   }
 
 #else
@@ -624,16 +630,16 @@ ListenAtTcpPortAndAddress(int port, const char *address)
   hints.ai_flags = AI_PASSIVE; /* fill in wildcard address if address == NULL */
 
   if (!initSockets())
-    return -1;
+    return INVALID_SOCKET;
 
   if ((rv = getaddrinfo(address, port_str, &hints, &servinfo)) != 0) {
     rfbClientErr("ListenAtTcpPortAndAddress: error in getaddrinfo: %s\n", gai_strerror(rv));
-    return -1;
+    return INVALID_SOCKET;
   }
 
   /* loop through all the results and bind to the first we can */
   for(p = servinfo; p != NULL; p = p->ai_next) {
-    if ((sock = socket(p->ai_family, p->ai_socktype, p->ai_protocol)) < 0) {
+    if ((sock = socket(p->ai_family, p->ai_socktype, p->ai_protocol)) == INVALID_SOCKET) {
       continue;
     }
 
@@ -643,7 +649,7 @@ ListenAtTcpPortAndAddress(int port, const char *address)
       rfbClientErr("ListenAtTcpPortAndAddress: error in setsockopt IPV6_V6ONLY: %s\n", strerror(errno));
       close(sock);
       freeaddrinfo(servinfo);
-      return -1;
+      return INVALID_SOCKET;
     }
 #endif
 
@@ -651,7 +657,7 @@ ListenAtTcpPortAndAddress(int port, const char *address)
       rfbClientErr("ListenAtTcpPortAndAddress: error in setsockopt SO_REUSEADDR: %s\n", strerror(errno));
       close(sock);
       freeaddrinfo(servinfo);
-      return -1;
+      return INVALID_SOCKET;
     }
 
     if (bind(sock, p->ai_addr, p->ai_addrlen) < 0) {
@@ -664,7 +670,7 @@ ListenAtTcpPortAndAddress(int port, const char *address)
 
   if (p == NULL)  {
     rfbClientErr("ListenAtTcpPortAndAddress: error in bind: %s\n", strerror(errno));
-    return -1;
+    return INVALID_SOCKET;
   }
 
   /* all done with this structure now */
@@ -674,7 +680,7 @@ ListenAtTcpPortAndAddress(int port, const char *address)
   if (listen(sock, 5) < 0) {
     rfbClientErr("ListenAtTcpPort: listen\n");
     close(sock);
-    return -1;
+    return INVALID_SOCKET;
   }
 
   return sock;
@@ -685,25 +691,25 @@ ListenAtTcpPortAndAddress(int port, const char *address)
  * AcceptTcpConnection accepts a TCP connection.
  */
 
-int
-AcceptTcpConnection(int listenSock)
+SOCKET
+AcceptTcpConnection(SOCKET listenSock)
 {
-  int sock;
+  SOCKET sock;
   struct sockaddr_in addr;
   socklen_t addrlen = sizeof(addr);
   int one = 1;
 
   sock = accept(listenSock, (struct sockaddr *) &addr, &addrlen);
-  if (sock < 0) {
+  if (sock == INVALID_SOCKET) {
     rfbClientErr("AcceptTcpConnection: accept\n");
-    return -1;
+    return INVALID_SOCKET;
   }
 
   if (setsockopt(sock, IPPROTO_TCP, TCP_NODELAY,
 		 (char *)&one, sizeof(one)) < 0) {
     rfbClientErr("AcceptTcpConnection: setsockopt\n");
     close(sock);
-    return -1;
+    return INVALID_SOCKET;
   }
 
   return sock;
@@ -715,7 +721,7 @@ AcceptTcpConnection(int listenSock)
  */
 
 rfbBool
-SetNonBlocking(int sock)
+SetNonBlocking(SOCKET sock)
 {
 #ifdef WIN32
   unsigned long block=1;
@@ -738,7 +744,7 @@ SetNonBlocking(int sock)
  */
 
 rfbBool
-SetDSCP(int sock, int dscp)
+SetDSCP(SOCKET sock, int dscp)
 {
 #ifdef WIN32
   rfbClientErr("Setting of QoS IP DSCP not implemented for Windows\n");
@@ -801,7 +807,7 @@ StringToIPAddr(const char *str, unsigned int *addr)
     return TRUE;
 
   if (!initSockets())
-	  return -1;
+	  return FALSE;
 
   hp = gethostbyname(str);
 
@@ -819,7 +825,7 @@ StringToIPAddr(const char *str, unsigned int *addr)
  */
 
 rfbBool
-SameMachine(int sock)
+SameMachine(SOCKET sock)
 {
   struct sockaddr_in peeraddr, myaddr;
   socklen_t addrlen = sizeof(struct sockaddr_in);
