@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2016-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef ACCESS_CONTROL_RULE_EDIT_DIALOG_H
-#define ACCESS_CONTROL_RULE_EDIT_DIALOG_H
+#pragma once
 
 #include <QDialog>
 
@@ -37,7 +36,7 @@ class AccessControlRuleEditDialog : public QDialog
 {
 	Q_OBJECT
 public:
-	AccessControlRuleEditDialog(AccessControlRule& rule, QWidget *parent = nullptr);
+	explicit AccessControlRuleEditDialog(AccessControlRule& rule, QWidget *parent = nullptr);
 	~AccessControlRuleEditDialog() override;
 
 	void accept() override;
@@ -49,5 +48,3 @@ private:
 	QMap<AccessControlRule::Subject, QString> m_subjectNameMap;
 
 };
-
-#endif // ACCESS_CONTROL_RULE_EDIT_DIALOG_H
