@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2016 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef ACCESS_CONTROL_RULE_LIST_MODEL_H
-#define ACCESS_CONTROL_RULE_LIST_MODEL_H
+#pragma once
 
 #include <QAbstractListModel>
 
@@ -45,5 +44,3 @@ private:
 	QList<AccessControlRule> m_accessControlRules;
 
 };
-
-#endif // ACCESS_CONTROL_RULE_LIST_MODEL_H
