@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2016-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,11 +22,11 @@
  *
  */
 
-#include <QHostInfo>
 #include <QMessageBox>
 
 #include "AccessControlRulesTestDialog.h"
 #include "AccessControlProvider.h"
+#include "HostAddress.h"
 #include "PlatformUserFunctions.h"
 
 #include "ui_AccessControlRulesTestDialog.h"
@@ -39,7 +39,7 @@ AccessControlRulesTestDialog::AccessControlRulesTestDialog(QWidget *parent) :
 	ui->setupUi(this);
 
 	ui->localUserLineEdit->setText( VeyonCore::platform().userFunctions().currentUser() );
-	ui->localComputerLineEdit->setText( QHostInfo::localHostName() );
+	ui->localComputerLineEdit->setText( HostAddress::localFQDN() );
 }
 
 
@@ -62,23 +62,23 @@ int AccessControlRulesTestDialog::exec()
 
 void AccessControlRulesTestDialog::accept()
 {
-	AccessControlRule::Action result =
+	const auto result =
 			AccessControlProvider().processAccessControlRules( ui->accessingUserLineEdit->text(),
 															   ui->accessingComputerLineEdit->text(),
 															   ui->localUserLineEdit->text(),
 															   ui->localComputerLineEdit->text(),
-															   ui->connectedUsersLineEdit->text().split( ',' ) );
+															   ui->connectedUsersLineEdit->text().split( QLatin1Char(',') ) );
 	QString resultText;
 
 	switch( result )
 	{
-	case AccessControlRule::ActionAllow:
+	case AccessControlRule::Action::Allow:
 		resultText = tr( "The access in the given scenario is allowed." );
 		break;
-	case AccessControlRule::ActionDeny:
+	case AccessControlRule::Action::Deny:
 		resultText = tr( "The access in the given scenario is denied." );
 		break;
-	case AccessControlRule::ActionAskForPermission:
+	case AccessControlRule::Action::AskForPermission:
 		resultText = tr( "The access in the given scenario needs permission of the logged on user." );
 		break;
 	default:
