@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -38,16 +38,15 @@
 MasterConfigurationPage::MasterConfigurationPage() :
 	ConfigurationPage(),
 	ui(new Ui::MasterConfigurationPage),
-	m_builtinFeatures( new BuiltinFeatures ),
 	m_featureManager()
 {
 	ui->setupUi(this);
 
-#define CONNECT_BUTTON_SLOT(name) \
-	connect( ui->name, SIGNAL( clicked() ), this, SLOT( name() ) );
+	connect( ui->openUserConfigurationDirectory, &QPushButton::clicked,
+			 this, &MasterConfigurationPage::openUserConfigurationDirectory );
 
-	CONNECT_BUTTON_SLOT( openUserConfigurationDirectory );
-	CONNECT_BUTTON_SLOT( openScreenshotDirectory );
+	connect( ui->openScreenshotDirectory, &QPushButton::clicked,
+			 this, &MasterConfigurationPage::openScreenshotDirectory );
 
 	populateFeatureComboBox();
 }
@@ -57,7 +56,6 @@ MasterConfigurationPage::MasterConfigurationPage() :
 MasterConfigurationPage::~MasterConfigurationPage()
 {
 	delete ui;
-	delete m_builtinFeatures;
 }
 
 
@@ -88,20 +86,6 @@ void MasterConfigurationPage::applyConfiguration()
 
 
 
-void MasterConfigurationPage::openUserConfigurationDirectory()
-{
-	FileSystemBrowser( FileSystemBrowser::ExistingFile ).exec( ui->userConfigurationDirectory );
-}
-
-
-
-void MasterConfigurationPage::openScreenshotDirectory()
-{
-	FileSystemBrowser( FileSystemBrowser::ExistingDirectory ).exec( ui->screenshotDirectory );
-}
-
-
-
 void MasterConfigurationPage::enableFeature()
 {
 	const auto items = ui->disabledFeaturesListWidget->selectedItems();
@@ -136,6 +120,20 @@ void MasterConfigurationPage::disableFeature()
 
 
 
+void MasterConfigurationPage::openUserConfigurationDirectory()
+{
+	FileSystemBrowser( FileSystemBrowser::ExistingFile ).exec( ui->userConfigurationDirectory );
+}
+
+
+
+void MasterConfigurationPage::openScreenshotDirectory()
+{
+	FileSystemBrowser( FileSystemBrowser::ExistingDirectory ).exec( ui->screenshotDirectory );
+}
+
+
+
 void MasterConfigurationPage::populateFeatureComboBox()
 {
 	ui->computerDoubleClickFeature->addItem( QIcon(), tr( "<no feature>" ), QUuid() );
@@ -165,7 +163,7 @@ void MasterConfigurationPage::updateFeatureLists()
 	for( const auto& feature : qAsConst( m_featureManager.features() ) )
 	{
 		if( feature.testFlag( Feature::Master ) == false ||
-				feature == m_builtinFeatures->monitoringMode().feature() )
+				feature == VeyonCore::builtinFeatures().monitoringMode().feature() )
 		{
 			continue;
 		}
