@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2011-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef ABOUT_DIALOG_H
-#define ABOUT_DIALOG_H
+#pragma once
 
 #include <QDialog>
 
@@ -38,7 +37,7 @@ class VEYON_CORE_EXPORT AboutDialog : public QDialog
 {
 	Q_OBJECT
 public:
-	AboutDialog( QWidget *parent );
+	explicit AboutDialog( QWidget *parent );
 	~AboutDialog() override;
 
 private slots:
@@ -47,5 +46,3 @@ private slots:
 private:
 	Ui::AboutDialog *ui;
 } ;
-
-#endif
