@@ -30,7 +30,6 @@ class DesktopAccessDialog;
 class FeatureControl;
 class MonitoringMode;
 class SystemTrayIcon;
-class UserSessionControl;
 
 // clazy:excludeall=rule-of-three
 
@@ -60,15 +59,9 @@ public:
 		return *m_desktopAccessDialog;
 	}
 
-	UserSessionControl& userSessionControl()
-	{
-		return *m_userSessionControl;
-	}
-
 private:
 	FeatureControl* m_featureControl;
 	SystemTrayIcon* m_systemTrayIcon;
 	MonitoringMode* m_monitoringMode;
 	DesktopAccessDialog* m_desktopAccessDialog;
-	UserSessionControl* m_userSessionControl;
 };
