@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef CONFIGURATION_JSON_STORE_H
-#define CONFIGURATION_JSON_STORE_H
+#pragma once
 
 #include "Configuration/Store.h"
 
@@ -35,7 +34,7 @@ namespace Configuration
 class VEYON_CORE_EXPORT JsonStore : public Store
 {
 public:
-	JsonStore( Scope scope, const QString & file = QString() );
+	explicit JsonStore( Scope scope, const QString & file = {} );
 
 	void load( Object *obj ) override;
 	void flush( const Object *obj ) override;
@@ -50,5 +49,3 @@ private:
 } ;
 
 }
-
-#endif
