@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2009-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef CONFIGURATION_LOCAL_STORE_H
-#define CONFIGURATION_LOCAL_STORE_H
+#pragma once
 
 #include "Configuration/Store.h"
 
@@ -37,7 +36,7 @@ namespace Configuration
 class VEYON_CORE_EXPORT LocalStore : public Store
 {
 public:
-	LocalStore( Scope scope );
+	explicit LocalStore( Scope scope );
 
 	void load( Object *obj ) override;
 	void flush( const Object *obj ) override;
@@ -49,5 +48,3 @@ public:
 } ;
 
 }
-
-#endif
