@@ -34,7 +34,7 @@ class VEYON_CORE_EXPORT Proxy : public QObject
 {
 	Q_OBJECT
 public:
-	explicit Proxy( Object* object, QObject* parent = nullptr );
+	explicit Proxy( Object* object );
 	~Proxy() override = default;
 
 	bool hasValue( const QString& key, const QString& parentKey ) const;
@@ -48,6 +48,11 @@ public:
 	void reloadFromStore();
 	void flushStore();
 
+	QObject* object() const
+	{
+		return m_object;
+	}
+
 	const QString& instanceId() const
 	{
 		return m_instanceId;
@@ -71,11 +76,11 @@ private:
 #define DECLARE_CONFIG_PROXY(name, ops) \
 	class name : public Configuration::Proxy { \
 	public: \
-		explicit name( Configuration::Object* object, QObject* parent = nullptr ); \
+		explicit name( Configuration::Object* object ); \
 		ops(DECLARE_CONFIG_PROPERTY) \
 	};
 
 #define IMPLEMENT_CONFIG_PROXY(name) \
-	name::name( Configuration::Object* object, QObject* parent ) : Configuration::Proxy( object, parent ) { }
+	name::name( Configuration::Object* object ) : Configuration::Proxy( object ) { }
 
 }
