@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2010-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef CONFIGURATION_MANAGER_H
-#define CONFIGURATION_MANAGER_H
+#pragma once
 
 #include "VeyonCore.h"
 
@@ -35,7 +34,7 @@ class VEYON_CORE_EXPORT ConfigurationManager : public QObject
 {
 	Q_OBJECT
 public:
-	ConfigurationManager( QObject* parent = nullptr );
+	explicit ConfigurationManager( QObject* parent = nullptr );
 
 	bool clearConfiguration();
 	bool applyConfiguration();
@@ -51,5 +50,3 @@ private:
 	QString m_errorString;
 
 } ;
-
-#endif
