@@ -37,6 +37,7 @@ public:
 	using PrivateKey = QCA::PrivateKey;
 	using PublicKey = QCA::PublicKey;
 	using SecureArray = QCA::SecureArray;
+	using PlaintextPassword = SecureArray;
 
 	enum {
 		RsaKeySize = 4096,
@@ -51,8 +52,8 @@ public:
 
 	static QByteArray generateChallenge();
 
-	QString encryptPassword( const QString& password ) const;
-	QString decryptPassword( const QString& encryptedPassword ) const;
+	QString encryptPassword( const PlaintextPassword& password ) const;
+	PlaintextPassword decryptPassword( const QString& encryptedPassword ) const;
 
 private:
 	QCA::Initializer m_qcaInitializer;
