@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef NETWORK_OBJECT_MODEL_H
-#define NETWORK_OBJECT_MODEL_H
+#pragma once
 
 #include <QAbstractItemModel>
 
@@ -33,12 +32,12 @@ class VEYON_CORE_EXPORT NetworkObjectModel : public QAbstractItemModel
 {
 	Q_OBJECT
 public:
-	NetworkObjectModel( QObject* parent = nullptr) :
+	explicit NetworkObjectModel( QObject* parent = nullptr) :
 		QAbstractItemModel( parent )
 	{
 	}
 
-	typedef enum Roles
+	enum Role
 	{
 		CheckStateRole = Qt::CheckStateRole,
 		NameRole = Qt::DisplayRole,
@@ -48,8 +47,6 @@ public:
 		MacAddressRole,
 		DirectoryAddressRole,
 		ParentUidRole
-	} Role;
+	} ;
 
 };
-
-#endif // NETWORK_OBJECT_MODEL_H
