@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef PLATFORM_INPUT_DEVICE_FUNCTIONS_H
-#define PLATFORM_INPUT_DEVICE_FUNCTIONS_H
+#pragma once
 
 #include "PlatformPluginInterface.h"
 
@@ -39,8 +38,4 @@ public:
 
 	virtual KeyboardShortcutTrapper* createKeyboardShortcutTrapper( QObject* parent ) = 0;
 
-	virtual bool configureSoftwareSAS( bool enabled ) = 0;
-
 };
-
-#endif // PLATFORM_INPUT_DEVICE_FUNCTIONS_H
