@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef PLATFORM_PLUGIN_MANAGER_H
-#define PLATFORM_PLUGIN_MANAGER_H
+#pragma once
 
 #include "PlatformPluginInterface.h"
 
@@ -31,7 +30,7 @@ class VEYON_CORE_EXPORT PlatformPluginManager : public QObject
 {
 	Q_OBJECT
 public:
-	PlatformPluginManager( PluginManager& pluginManager, QObject* parent = nullptr );
+	explicit PlatformPluginManager( PluginManager& pluginManager, QObject* parent = nullptr );
 
 	PlatformPluginInterface* platformPlugin()
 	{
@@ -42,5 +41,3 @@ private:
 	PlatformPluginInterface* m_platformPlugin;
 
 };
-
-#endif // PLATFORM_PLUGIN_MANAGER_H
