@@ -24,6 +24,7 @@
 
 #pragma once
 
+#include "CryptoCore.h"
 #include "PlatformPluginInterface.h"
 
 // clazy:excludeall=copyable-polymorphic
@@ -31,6 +32,8 @@
 class PlatformUserFunctions
 {
 public:
+	using Password = CryptoCore::SecureArray;
+
 	virtual ~PlatformUserFunctions() = default;
 
 	virtual QString fullName( const QString& username ) = 0;
@@ -41,9 +44,10 @@ public:
 	virtual bool isAnyUserLoggedOn() = 0;
 	virtual QString currentUser() = 0;
 
-	virtual void logon( const QString& username, const QString& password ) = 0;
+	virtual bool prepareLogon( const QString& username, const Password& password ) = 0;
+	virtual bool performLogon( const QString& username, const Password& password ) = 0;
 	virtual void logoff() = 0;
 
-	virtual bool authenticate( const QString& username, const QString& password ) = 0;
+	virtual bool authenticate( const QString& username, const Password& password ) = 0;
 
 };
