@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef PLUGIN_H
-#define PLUGIN_H
+#pragma once
 
 #include <QObject>
 #include <QList>
@@ -33,12 +32,13 @@ class Plugin
 {
 	Q_GADGET
 public:
-	typedef QUuid Uid;
+	using Uid = QUuid;
 
 	enum PluginFlags
 	{
 		NoFlags,
 		ProvidesDefaultImplementation = 0x0001,
+		RequiresLicensing = 0x002,
 	} ;
 
 	Q_DECLARE_FLAGS(Flags, PluginFlags)
@@ -46,6 +46,4 @@ public:
 
 };
 
-typedef QList<Plugin::Uid> PluginUidList;
-
-#endif // PLUGIN_H
+using PluginUidList = QList<Plugin::Uid>;
