@@ -3,7 +3,7 @@
  *
  *  Copyright (c) 2006-2019 Tobias Junghans <tobydox@veyon.io>
  *
- *  This file is part of Veyon - http://veyon.io
+ *  This file is part of Veyon - https://veyon.io
  *
  *  This is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,8 +21,7 @@
  *  USA.
  */
 
-#ifndef PROGRESS_WIDGET_H
-#define PROGRESS_WIDGET_H
+#pragma once
 
 #include <QPixmap>
 #include <QVector>
@@ -33,15 +32,14 @@ class ProgressWidget : public QWidget
 	Q_OBJECT
 public:
 	ProgressWidget( const QString& text, const QString& animationPixmapBase, int frames, QWidget* parent = nullptr );
-	~ProgressWidget() override;
+	~ProgressWidget() override = default;
 
 protected:
 	void paintEvent( QPaintEvent* event ) override;
 
-private slots:
+private:
 	void nextFrame();
 
-private:
 	QString m_text;
 	int m_frames;
 	int m_curFrame;
@@ -49,5 +47,3 @@ private:
 	QVector<QPixmap> m_pixmaps;
 
 } ;
-
-#endif
