@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef USER_GROUPS_BACKEND_MANAGER_H
-#define USER_GROUPS_BACKEND_MANAGER_H
+#pragma once
 
 #include "UserGroupsBackendInterface.h"
 
@@ -31,7 +30,7 @@ class VEYON_CORE_EXPORT UserGroupsBackendManager : public QObject
 {
 	Q_OBJECT
 public:
-	UserGroupsBackendManager( QObject* parent = nullptr );
+	explicit UserGroupsBackendManager( QObject* parent = nullptr );
 
 	QMap<Plugin::Uid, QString> availableBackends();
 
@@ -45,5 +44,3 @@ private:
 	UserGroupsBackendInterface* m_accessControlBackend;
 
 };
-
-#endif // USER_GROUPS_BACKEND_MANAGER_H
