@@ -71,7 +71,17 @@ public:
 	};
 	Q_ENUM(ApplicationVersion)
 
-	VeyonCore( QCoreApplication* application, const QString& appComponentName );
+	enum class Component {
+		Service,
+		Server,
+		Worker,
+		Master,
+		CLI,
+		Configurator
+	};
+	Q_ENUM(Component)
+
+	VeyonCore( QCoreApplication* application, Component component, const QString& appComponentName );
 	~VeyonCore() override;
 
 	static VeyonCore* instance();
@@ -85,6 +95,11 @@ public:
 
 	static QString sessionIdEnvironmentVariable();
 
+	static Component component()
+	{
+		return instance()->m_component;
+	}
+
 	static VeyonConfiguration& config()
 	{
 		return *( instance()->m_config );
@@ -198,6 +213,7 @@ private:
 
 	ComputerControlInterface* m_localComputerControlInterface;
 
+	Component m_component;
 	QString m_applicationName;
 	QString m_authenticationKeyName;
 	bool m_debugging;
