@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2018-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,16 +22,27 @@
  *
  */
 
-#ifndef VEYON_MASTER_INTERFACE_H
-#define VEYON_MASTER_INTERFACE_H
+#pragma once
 
+#include "Configuration/Object.h"
+#include "VeyonCore.h"
+
+class BuiltinFeatures;
 class QWidget;
 
-class VeyonMasterInterface
+class VEYON_CORE_EXPORT VeyonMasterInterface : public QObject
 {
+	Q_OBJECT
 public:
+	explicit VeyonMasterInterface( QObject* parent ) :
+		QObject( parent )
+	{
+	}
+
+	~VeyonMasterInterface() override = default;
+
 	virtual QWidget* mainWindow() = 0;
+	virtual Configuration::Object* userConfigurationObject() = 0;
+	virtual void reloadSubFeatures() = 0;
 
 };
-
-#endif
