@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2018-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,18 +22,19 @@
  *
  */
 
-#ifndef VEYON_SERVER_INTERFACE_H
-#define VEYON_SERVER_INTERFACE_H
+#pragma once
 
+class BuiltinFeatures;
 class FeatureMessage;
 class FeatureWorkerManager;
+class MessageContext;
 
 class VeyonServerInterface
 {
 public:
+	virtual ~VeyonServerInterface() = default;
+
 	virtual FeatureWorkerManager& featureWorkerManager() = 0;
-	virtual bool sendFeatureMessageReply( const FeatureMessage& request, const FeatureMessage& reply ) = 0;
+	virtual bool sendFeatureMessageReply( const MessageContext& context, const FeatureMessage& reply ) = 0;
 
 };
-
-#endif
