@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef VEYON_SERVICE_CONTROL_H
-#define VEYON_SERVICE_CONTROL_H
+#pragma once
 
 #include "ServiceControl.h"
 
@@ -33,7 +32,7 @@ class VEYON_CORE_EXPORT VeyonServiceControl : public ServiceControl
 {
 	Q_OBJECT
 public:
-	VeyonServiceControl( QWidget* parent = nullptr );
+	explicit VeyonServiceControl( QWidget* parent = nullptr );
 
 	bool setAutostart( bool enabled );
 
@@ -41,5 +40,3 @@ public:
 	static QString filePath();
 	static QString displayName();
 };
-
-#endif // VEYON_SERVICE_CONTROL_H
