@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2018-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,13 +22,16 @@
  *
  */
 
-#ifndef VEYON_WORKER_INTERFACE_H
-#define VEYON_WORKER_INTERFACE_H
+#pragma once
+
+class BuiltinFeatures;
+class FeatureMessage;
 
 class VeyonWorkerInterface
 {
 public:
+	virtual ~VeyonWorkerInterface() = default;
+
+	virtual bool sendFeatureMessageReply( const FeatureMessage& reply ) = 0;
 
 };
-
-#endif
