@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2011-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -43,11 +43,11 @@ AboutDialog::AboutDialog( QWidget *parent ) :
 
 	QFile authors( QStringLiteral( ":/CONTRIBUTORS" ) );
 	authors.open( QFile::ReadOnly ); // Flawfinder: ignore
-	ui->authors->setPlainText( authors.readAll() );
+	ui->authors->setPlainText( QString::fromUtf8( authors.readAll() ) );
 
-	QFile license( QStringLiteral( ":/COPYING" ) );
+	QFile license( QStringLiteral( ":/core/COPYING" ) );
 	license.open( QFile::ReadOnly ); // Flawfinder: ignore
-	ui->license->setPlainText( license.readAll() );
+	ui->license->setPlainText( QString::fromUtf8( license.readAll() ) );
 
 	VeyonCore::enforceBranding( this );
 }
