@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2009-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,7 +22,9 @@
  *
  */
 
+#include <QJsonArray>
 #include <QJsonDocument>
+#include <QJsonObject>
 #include <QSettings>
 
 #include "Configuration/LocalStore.h"
@@ -48,7 +50,7 @@ static void loadSettingsTree( Object *obj, QSettings *s,
 	for( const auto& g : childGroups )
 	{
 		const QString subParentKey = parentKey +
-									( parentKey.isEmpty() ? "" : "/" ) + g;
+									( parentKey.isEmpty() ? QString() : QStringLiteral("/") ) + g;
 		s->beginGroup( g );
 		loadSettingsTree( obj, s, subParentKey );
 		s->endGroup();
@@ -74,7 +76,7 @@ static void loadSettingsTree( Object *obj, QSettings *s,
 			}
 			else
 			{
-				qCritical( "LocalStore: trying to load unknown JSON value type!" );
+				vCritical() << "trying to load unknown JSON value type!";
 			}
 		}
 		else
@@ -89,7 +91,7 @@ static void loadSettingsTree( Object *obj, QSettings *s,
 void LocalStore::load( Object *obj )
 {
 	auto s = createSettingsObject();
-	loadSettingsTree( obj, s, QString() );
+	loadSettingsTree( obj, s, {} );
 	delete s;
 }
 
@@ -109,10 +111,11 @@ static QString serializeJsonValue( const QJsonValue& jsonValue )
 	}
 	else
 	{
-		qCritical( "LocalStore: trying to save unknown JSON value type %d!", (int) jsonValue.type() );
+		vCritical() << "trying to save unknown JSON value type" << jsonValue.type();
 	}
 
-	return QStringLiteral("@JsonValue(%1)").arg( QString( QJsonDocument( jsonObject ).toJson( QJsonDocument::Compact ).toBase64() ) );
+	return QStringLiteral("@JsonValue(%1)").arg(
+				QString::fromLatin1( QJsonDocument( jsonObject ).toJson( QJsonDocument::Compact ).toBase64() ) );
 }
 
 
@@ -135,6 +138,10 @@ static void saveSettingsTree( const Object::DataMap &dataMap, QSettings *s )
 		{
 			s->setValue( it.key(), serializeJsonValue( it.value().toJsonObject() ) );
 		}
+		else if( QMetaType( it.value().userType() ).flags().testFlag( QMetaType::IsEnumeration ) )
+		{
+			s->setValue( it.key(), it.value().toInt() );
+		}
 		else
 		{
 			s->setValue( it.key(), it.value() );
