@@ -73,22 +73,22 @@ QByteArray CryptoCore::generateChallenge()
 
 
 
-QString CryptoCore::encryptPassword( const QString& password ) const
+QString CryptoCore::encryptPassword( const PlaintextPassword& password ) const
 {
 	return QString::fromLatin1( m_defaultPrivateKey.toPublicKey().
-								encrypt( password.toUtf8(), DefaultEncryptionAlgorithm ).toByteArray().toHex() );
+								encrypt( password, DefaultEncryptionAlgorithm ).toByteArray().toHex() );
 }
 
 
 
-QString CryptoCore::decryptPassword( const QString& encryptedPassword ) const
+CryptoCore::PlaintextPassword CryptoCore::decryptPassword( const QString& encryptedPassword ) const
 {
-	SecureArray decryptedPassword;
+	PlaintextPassword decryptedPassword;
 
 	if( PrivateKey( m_defaultPrivateKey ).decrypt( QByteArray::fromHex( encryptedPassword.toUtf8() ),
 												   &decryptedPassword, DefaultEncryptionAlgorithm ) )
 	{
-		return QString::fromUtf8( decryptedPassword.toByteArray() );
+		return decryptedPassword;
 	}
 
 	vCritical() << "failed to decrypt password!";
