@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -42,7 +42,7 @@ VariantArrayMessage::VariantArrayMessage( QIODevice* ioDevice ) :
 
 bool VariantArrayMessage::send()
 {
-	MessageSize messageSize = qToBigEndian<MessageSize>( static_cast<MessageSize>( m_buffer.size() ) );
+	const auto messageSize = qToBigEndian<MessageSize>( static_cast<MessageSize>( m_buffer.size() ) );
 	m_ioDevice->write( reinterpret_cast<const char *>( &messageSize ), sizeof(messageSize) );
 	m_ioDevice->write( m_buffer.data() );
 
@@ -59,7 +59,7 @@ bool VariantArrayMessage::isReadyForReceive()
 	{
 		messageSize = qFromBigEndian(messageSize);
 
-		return m_ioDevice->bytesAvailable() >= static_cast<qint64>( sizeof(messageSize) + messageSize );
+		return m_ioDevice->bytesAvailable() >= static_cast<MessageSize>( sizeof(messageSize) + messageSize );
 	}
 
 	return false;
@@ -73,21 +73,21 @@ bool VariantArrayMessage::receive()
 
 	if( m_ioDevice->read( reinterpret_cast<char *>( &messageSize ), sizeof(messageSize) ) != sizeof(messageSize) ) // Flawfinder: ignore
 	{
-		qWarning( "VariantArrayMessage::receive(): could not read message size!" );
+		vWarning() << "could not read message size!";
 		return false;
 	}
 
 	messageSize = qFromBigEndian(messageSize);
 	if( messageSize > MaxMessageSize )
 	{
-		qCritical() << Q_FUNC_INFO << "invalid message size" << messageSize;
+		vCritical() << "invalid message size" << messageSize;
 		return false;
 	}
 
 	const auto data = m_ioDevice->read( messageSize ); // Flawfinder: ignore
 	if( data.size() != static_cast<qint64>( messageSize ) )
 	{
-		qWarning( "VariantArrayMessage::receive(): could not read message data!" );
+		vWarning() << "could not read message data!";
 		return false;
 	}
 
