@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -39,7 +39,7 @@ QVariant VariantStream::read() // Flawfinder: ignore
 
 	if( v.isValid() == false || v.isNull() )
 	{
-		qWarning( "VariantStream: none or invalid data read" );
+		vWarning() << "none or invalid data read";
 	}
 
 	return v;
