@@ -66,10 +66,10 @@ vncEncryptBytes(unsigned char *bytes, const char *passwd, size_t passwd_length)
 
 
 
-VncClientProtocol::VncClientProtocol( QTcpSocket* socket, const QString& vncPassword ) :
+VncClientProtocol::VncClientProtocol( QTcpSocket* socket, const Password& vncPassword ) :
 	m_socket( socket ),
 	m_state( Disconnected ),
-	m_vncPassword( vncPassword.toUtf8() ),
+	m_vncPassword( vncPassword ),
 	m_serverInitMessage(),
 	m_pixelFormat( { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 } ),
 	m_framebufferWidth( 0 ),
@@ -183,6 +183,13 @@ void VncClientProtocol::requestFramebufferUpdate( bool incremental )
 
 bool VncClientProtocol::receiveMessage()
 {
+	if( m_socket->bytesAvailable() > MaximumMessageSize )
+	{
+		vCritical() << "Message too big or invalid";
+		m_socket->close();
+		return false;
+	}
+
 	uint8_t messageType = 0;
 	if( m_socket->peek( reinterpret_cast<char *>( &messageType ), sizeof(messageType) ) != sizeof(messageType) )
 	{
@@ -485,7 +492,7 @@ bool VncClientProtocol::receiveCutTextMessage()
 		return false;
 	}
 
-	return readMessage( sz_rfbServerCutTextMsg + qFromBigEndian( message.length ) );
+	return readMessage( sz_rfbServerCutTextMsg + static_cast<int>( qFromBigEndian( message.length ) ) );
 }
 
 
