@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2008-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * code partly taken from KRDC / vncclientthread.cpp:
  * Copyright (C) 2007-2008 Urs Wolfer <uwolfer @ kde.org>
@@ -25,92 +25,19 @@
  *
  */
 
+#include <rfb/rfbclient.h>
+
 #include <QBitmap>
-#include <QElapsedTimer>
 #include <QHostAddress>
 #include <QMutexLocker>
 #include <QPixmap>
 #include <QTime>
 
-#include "AuthenticationCredentials.h"
-#include "CryptoCore.h"
 #include "PlatformNetworkFunctions.h"
-#include "PlatformUserFunctions.h"
 #include "VeyonConfiguration.h"
 #include "VncConnection.h"
 #include "SocketDevice.h"
-#include "VariantArrayMessage.h"
-
-extern "C"
-{
-#include <rfb/rfbclient.h>
-}
-
-// clazy:excludeall=copyable-polymorphic
-
-class KeyClientEvent : public MessageEvent
-{
-public:
-	KeyClientEvent( unsigned int key, bool pressed ) :
-		m_key( key ),
-		m_pressed( pressed )
-	{
-	}
-
-	void fire( rfbClient* client ) override
-	{
-		SendKeyEvent( client, m_key, m_pressed );
-	}
-
-private:
-	unsigned int m_key;
-	bool m_pressed;
-} ;
-
-
-
-class PointerClientEvent : public MessageEvent
-{
-public:
-	PointerClientEvent( int x, int y, int buttonMask ) :
-		m_x( x ),
-		m_y( y ),
-		m_buttonMask( buttonMask )
-	{
-	}
-
-	void fire( rfbClient* client ) override
-	{
-		SendPointerEvent( client, m_x, m_y, m_buttonMask );
-	}
-
-private:
-	int m_x;
-	int m_y;
-	int m_buttonMask;
-} ;
-
-
-
-class ClientCutEvent : public MessageEvent
-{
-public:
-	ClientCutEvent( const QString& text ) :
-		m_text( text.toUtf8() )
-	{
-	}
-
-	void fire( rfbClient* client ) override
-	{
-		SendClientCutText( client, m_text.data(), m_text.size() ); // clazy:exclude=detaching-member
-	}
-
-private:
-	QByteArray m_text;
-} ;
-
-
-
+#include "VncEvents.h"
 
 
 rfbBool VncConnection::hookInitFrameBuffer( rfbClient* client )
@@ -169,7 +96,7 @@ void VncConnection::hookCursorShape( rfbClient* client, int xh, int yh, int w, i
 {
 	if( bpp != 4 )
 	{
-		qWarning() << Q_FUNC_INFO << QThread::currentThreadId() << "bytes per pixel != 4";
+		vWarning() << QThread::currentThreadId() << "bytes per pixel != 4";
 		return;
 	}
 
@@ -206,15 +133,15 @@ void VncConnection::rfbClientLogDebug( const char* format, ... )
 	va_list args;
 	va_start( args, format );
 
-	static const int MaxMessageLength = 256;
+	static constexpr int MaxMessageLength = 256;
 	char message[MaxMessageLength];
 
-	vsnprintf( message, MaxMessageLength, format, args );
+	vsnprintf( message, sizeof(message), format, args );
 	message[MaxMessageLength-1] = 0;
 
 	va_end(args);
 
-	qDebug() << Q_FUNC_INFO << QThread::currentThreadId() << message;
+	vDebug() << QThread::currentThreadId() << message;
 }
 
 
@@ -229,7 +156,7 @@ void VncConnection::rfbClientLogNone( const char* format, ... )
 
 void VncConnection::framebufferCleanup( void* framebuffer )
 {
-	delete[] static_cast<uchar *>( framebuffer );
+	delete[] static_cast<RfbPixel *>( framebuffer );
 }
 
 
@@ -237,16 +164,15 @@ void VncConnection::framebufferCleanup( void* framebuffer )
 
 VncConnection::VncConnection( QObject* parent ) :
 	QThread( parent ),
-	m_state( Disconnected ),
-	m_framebufferState( FramebufferInvalid ),
+	m_state( State::Disconnected ),
+	m_framebufferState( FramebufferState::Invalid ),
 	m_controlFlags(),
 	m_client( nullptr ),
-	m_quality( DefaultQuality ),
+	m_quality( Quality::Default ),
 	m_host(),
 	m_port( -1 ),
-	m_veyonAuthType( RfbVeyonAuth::Logon ),
 	m_globalMutex(),
-	m_controlFlagMutex(),
+	m_eventQueueMutex(),
 	m_updateIntervalSleeper(),
 	m_framebufferUpdateInterval( 0 ),
 	m_image(),
@@ -254,10 +180,6 @@ VncConnection::VncConnection( QObject* parent ) :
 	m_scaledSize(),
 	m_imgLock()
 {
-	if( VeyonCore::config().authenticationMethod() == VeyonCore::KeyFileAuthentication )
-	{
-		m_veyonAuthType = RfbVeyonAuth::KeyFile;
-	}
 }
 
 
@@ -268,13 +190,13 @@ VncConnection::~VncConnection()
 
 	if( isRunning() )
 	{
-		qWarning( "Waiting for VNC connection thread to finish." );
+		vWarning() << "Waiting for VNC connection thread to finish.";
 		wait( ThreadTerminationTimeout );
 	}
 
 	if( isRunning() )
 	{
-		qWarning( "Terminating hanging VNC connection thread!" );
+		vWarning() << "Terminating hanging VNC connection thread!";
 
 		terminate();
 		wait();
@@ -299,7 +221,7 @@ void VncConnection::initLogging( bool debug )
 
 
 
-QImage VncConnection::image() const
+QImage VncConnection::image()
 {
 	QReadLocker locker( &m_imgLock );
 	return m_image;
@@ -309,7 +231,7 @@ QImage VncConnection::image() const
 
 void VncConnection::restart()
 {
-	setControlFlag( RestartConnection, true );
+	setControlFlag( ControlFlag::RestartConnection, true );
 }
 
 
@@ -318,9 +240,9 @@ void VncConnection::stop()
 {
 	setClientData( VncConnectionTag, nullptr );
 
-	m_scaledScreen = QImage();
+	m_scaledScreen = {};
 
-	setControlFlag( TerminateThread, true );
+	setControlFlag( ControlFlag::TerminateThread, true );
 
 	m_updateIntervalSleeper.wakeAll();
 }
@@ -348,21 +270,21 @@ void VncConnection::setHost( const QString& host )
 	m_host = host;
 
 	// is IPv6-mapped IPv4 address?
-	QRegExp rx( "::[fF]{4}:(\\d+.\\d+.\\d+.\\d+)" );
+	QRegExp rx( QStringLiteral( "::[fF]{4}:(\\d+.\\d+.\\d+.\\d+)" ) );
 	if( rx.indexIn( m_host ) == 0 )
 	{
 		// then use plain IPv4 address as libvncclient cannot handle
 		// IPv6-mapped IPv4 addresses on Windows properly
 		m_host = rx.cap( 1 );
 	}
-	else if( m_host == QStringLiteral( "::1" ) )
+	else if( m_host == QLatin1String( "::1" ) )
 	{
 		m_host = QHostAddress( QHostAddress::LocalHost ).toString();
 	}
-	else if( m_host.count( ':' ) == 1 )
+	else if( m_host.count( QLatin1Char(':') ) == 1 )
 	{
-		// host name + port number?
-		QRegExp rx2( "(.*[^:]):(\\d+)$" );
+		// hostname + port number?
+		QRegExp rx2( QStringLiteral("(.*[^:]):(\\d+)$") );
 		if( rx2.indexIn( m_host ) == 0 )
 		{
 			m_host = rx2.cap( 1 );
@@ -384,6 +306,34 @@ void VncConnection::setPort( int port )
 
 
 
+void VncConnection::setServerReachable()
+{
+	setControlFlag( ControlFlag::ServerReachable, true );
+}
+
+
+
+void VncConnection::setScaledSize( QSize s )
+{
+	QMutexLocker globalLock( &m_globalMutex );
+
+	if( m_scaledSize != s )
+	{
+		m_scaledSize = s;
+		setControlFlag( ControlFlag::ScaledScreenNeedsUpdate, true );
+	}
+}
+
+
+
+QImage VncConnection::scaledScreen()
+{
+	rescaleScreen();
+	return m_scaledScreen;
+}
+
+
+
 void VncConnection::setFramebufferUpdateInterval( int interval )
 {
 	m_framebufferUpdateInterval = interval;
@@ -391,21 +341,29 @@ void VncConnection::setFramebufferUpdateInterval( int interval )
 
 
 
-
 void VncConnection::rescaleScreen()
 {
-	if( m_image.size().isValid() == false ||
-			m_scaledSize.isNull() ||
-			hasValidFrameBuffer() == false ||
-			isControlFlagSet( ScaledScreenNeedsUpdate ) == false )
+	if( hasValidFrameBuffer() == false || m_scaledSize.isNull() )
+	{
+		m_scaledScreen = {};
+		return;
+	}
+
+	if( isControlFlagSet( ControlFlag::ScaledScreenNeedsUpdate ) == false )
 	{
 		return;
 	}
 
 	QReadLocker locker( &m_imgLock );
+
+	if( m_image.size().isValid() == false )
+	{
+		return;
+	}
+
 	m_scaledScreen = m_image.scaled( m_scaledSize, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
 
-	setControlFlag( ScaledScreenNeedsUpdate, false );
+	setControlFlag( ControlFlag::ScaledScreenNeedsUpdate, false );
 }
 
 
@@ -424,21 +382,19 @@ void* VncConnection::clientData( rfbClient* client, int tag )
 
 void VncConnection::setClientData( int tag, void* data )
 {
-	m_globalMutex.lock();
+	QMutexLocker globalLock( &m_globalMutex );
 
 	if( m_client )
 	{
 		rfbClientSetClientData( m_client, reinterpret_cast<void *>( tag ), data );
 	}
-
-	m_globalMutex.unlock();
 }
 
 
 
 void VncConnection::run()
 {
-	while( isControlFlagSet( TerminateThread ) == false )
+	while( isControlFlagSet( ControlFlag::TerminateThread ) == false )
 	{
 		establishConnection();
 		handleConnection();
@@ -452,12 +408,13 @@ void VncConnection::establishConnection()
 {
 	QMutex sleeperMutex;
 
-	setState( Connecting );
-	setControlFlag( RestartConnection, false );
+	setState( State::Connecting );
+	setControlFlag( ControlFlag::RestartConnection, false );
 
-	m_framebufferState = FramebufferInvalid;
+	m_framebufferState = FramebufferState::Invalid;
 
-	while( isControlFlagSet( TerminateThread ) == false && m_state != Connected ) // try to connect as long as the server allows
+	while( isControlFlagSet( ControlFlag::TerminateThread ) == false &&
+		   state() != State::Connected ) // try to connect as long as the server allows
 	{
 		m_client = rfbGetClient( RfbBitsPerSample, RfbSamplesPerPixel, RfbBytesPerPixel );
 		m_client->MallocFrameBuffer = hookInitFrameBuffer;
@@ -469,6 +426,8 @@ void VncConnection::establishConnection()
 		m_client->GotXCutText = hookCutText;
 		setClientData( VncConnectionTag, this );
 
+		emit connectionPrepared();
+
 		m_globalMutex.lock();
 
 		if( m_port < 0 ) // use default port?
@@ -485,17 +444,20 @@ void VncConnection::establishConnection()
 
 		m_globalMutex.unlock();
 
-		setControlFlag( ServerReachable, false );
+		setControlFlag( ControlFlag::ServerReachable, false );
 
 		if( rfbInitClient( m_client, nullptr, nullptr ) &&
-				isControlFlagSet( TerminateThread ) == false )
+			isControlFlagSet( ControlFlag::TerminateThread ) == false )
 		{
+			m_framebufferUpdateWatchdog.restart();
+
 			emit connectionEstablished();
 
-			VeyonCore::platform().networkFunctions().configureSocketKeepalive( m_client->sock, true, SocketKeepaliveIdleTime,
-																			   SocketKeepaliveInterval, SocketKeepaliveCount );
+			VeyonCore::platform().networkFunctions().
+					configureSocketKeepalive( static_cast<PlatformNetworkFunctions::Socket>( m_client->sock ), true,
+											  SocketKeepaliveIdleTime, SocketKeepaliveInterval, SocketKeepaliveCount );
 
-			setState( Connected );
+			setState( State::Connected );
 		}
 		else
 		{
@@ -503,43 +465,43 @@ void VncConnection::establishConnection()
 			m_client = nullptr;
 
 			// do not sleep when already requested to stop
-			if( isControlFlagSet( TerminateThread ) )
+			if( isControlFlagSet( ControlFlag::TerminateThread ) )
 			{
 				break;
 			}
 
 			// guess reason why connection failed
-			if( isControlFlagSet( ServerReachable ) == false )
+			if( isControlFlagSet( ControlFlag::ServerReachable ) == false )
 			{
 				if( VeyonCore::platform().networkFunctions().ping( m_host ) == false )
 				{
-					setState( HostOffline );
+					setState( State::HostOffline );
 				}
 				else
 				{
-					setState( ServiceUnreachable );
+					setState( State::ServiceUnreachable );
 				}
 			}
-			else if( m_framebufferState == FramebufferInvalid )
+			else if( m_framebufferState == FramebufferState::Invalid )
 			{
-				setState( AuthenticationFailed );
+				setState( State::AuthenticationFailed );
 			}
 			else
 			{
 				// failed for an unknown reason
-				setState( ConnectionFailed );
+				setState( State::ConnectionFailed );
 			}
 
 			// wait a bit until next connect
 			sleeperMutex.lock();
 			if( m_framebufferUpdateInterval > 0 )
 			{
-				m_updateIntervalSleeper.wait( &sleeperMutex, static_cast<unsigned long>( m_framebufferUpdateInterval ) );
+				m_updateIntervalSleeper.wait( &sleeperMutex, QDeadlineTimer( m_framebufferUpdateInterval ) );
 			}
 			else
 			{
 				// default: retry every second
-				m_updateIntervalSleeper.wait( &sleeperMutex, ConnectionRetryInterval );
+				m_updateIntervalSleeper.wait( &sleeperMutex, QDeadlineTimer( ConnectionRetryInterval ) );
 			}
 			sleeperMutex.unlock();
 		}
@@ -553,14 +515,14 @@ void VncConnection::handleConnection()
 	QMutex sleeperMutex;
 	QElapsedTimer loopTimer;
 
-	while( state() == Connected &&
-		   isControlFlagSet( TerminateThread ) == false &&
-		   isControlFlagSet( RestartConnection ) == false )
+	while( state() == State::Connected &&
+		   isControlFlagSet( ControlFlag::TerminateThread ) == false &&
+		   isControlFlagSet( ControlFlag::RestartConnection ) == false )
 	{
 		loopTimer.start();
 
 		const int i = WaitForMessage( m_client, MessageWaitTimeout );
-		if( isControlFlagSet( TerminateThread ) || i < 0 )
+		if( isControlFlagSet( ControlFlag::TerminateThread ) || i < 0 )
 		{
 			break;
 		}
@@ -582,17 +544,28 @@ void VncConnection::handleConnection()
 
 		const auto remainingUpdateInterval = m_framebufferUpdateInterval - loopTimer.elapsed();
 
-		if( m_framebufferState == FramebufferValid &&
-				remainingUpdateInterval > 0 &&
-				isControlFlagSet( TerminateThread ) == false )
+		if( m_framebufferState == FramebufferState::Initialized ||
+			m_framebufferUpdateWatchdog.elapsed() >= qMax<qint64>( 2*m_framebufferUpdateInterval, FramebufferUpdateWatchdogTimeout ) )
 		{
+			SendFramebufferUpdateRequest( m_client, 0, 0, m_client->width, m_client->height, false );
+
+			const auto remainingFastUpdateInterval = FastFramebufferUpdateInterval - loopTimer.elapsed();
+
 			sleeperMutex.lock();
-			m_updateIntervalSleeper.wait( &sleeperMutex, static_cast<unsigned long>( remainingUpdateInterval ) );
+			m_updateIntervalSleeper.wait( &sleeperMutex, QDeadlineTimer( remainingFastUpdateInterval ) );
+			sleeperMutex.unlock();
+		}
+		else if( m_framebufferState == FramebufferState::Valid &&
+			remainingUpdateInterval > 0 &&
+			isControlFlagSet( ControlFlag::TerminateThread ) == false )
+		{
+			sleeperMutex.lock();
+			m_updateIntervalSleeper.wait( &sleeperMutex, QDeadlineTimer( remainingUpdateInterval ) );
 			sleeperMutex.unlock();
 		}
-	}
 
-	sendEvents();
+		sendEvents();
+	}
 }
 
 
@@ -605,17 +578,15 @@ void VncConnection::closeConnection()
 		m_client = nullptr;
 	}
 
-	setState( Disconnected );
+	setState( State::Disconnected );
 }
 
 
 
 void VncConnection::setState( State state )
 {
-	if( state != m_state )
+	if( m_state.exchange( state ) != state )
 	{
-		m_state = state;
-
 		emit stateChanged();
 	}
 }
@@ -624,29 +595,21 @@ void VncConnection::setState( State state )
 
 void VncConnection::setControlFlag( VncConnection::ControlFlag flag, bool on )
 {
-	m_controlFlagMutex.lock();
-#if (QT_VERSION < QT_VERSION_CHECK(5, 7, 0))
-#warning building compat code for Qt < 5.7
 	if( on )
 	{
-		m_controlFlags |= flag;
+		m_controlFlags |= static_cast<int>( flag );
 	}
 	else
 	{
-		m_controlFlags &= ~static_cast<unsigned int>( flag );
+		m_controlFlags &= ~static_cast<int>( flag );
 	}
-#else
-	m_controlFlags.setFlag( flag, on );
-#endif
-	m_controlFlagMutex.unlock();
 }
 
 
 
 bool VncConnection::isControlFlagSet( VncConnection::ControlFlag flag )
 {
-	QMutexLocker locker( &m_controlFlagMutex );
-	return m_controlFlags.testFlag( flag );
+	return m_controlFlags & static_cast<int>( flag );
 }
 
 
@@ -654,11 +617,17 @@ bool VncConnection::isControlFlagSet( VncConnection::ControlFlag flag )
 
 bool VncConnection::initFrameBuffer( rfbClient* client )
 {
-	const auto size = static_cast<uint64_t>( client->width * client->height * ( client->format.bitsPerPixel / 8 ) );
+	if( client->format.bitsPerPixel != RfbBitsPerSample * RfbBytesPerPixel )
+	{
+		vCritical() << "Bits per pixel does not match" << client->format.bitsPerPixel;
+		return false;
+	}
 
-	client->frameBuffer = new uint8_t[size];
+	const auto pixelCount = static_cast<uint32_t>( client->width ) * client->height;
 
-	memset( client->frameBuffer, '\0', size );
+	client->frameBuffer = reinterpret_cast<uint8_t *>( new RfbPixel[pixelCount] );
+
+	memset( client->frameBuffer, '\0', pixelCount*RfbBytesPerPixel );
 
 	// initialize framebuffer image which just wraps the allocated memory and ensures cleanup after last
 	// image copy using the framebuffer gets destroyed
@@ -667,7 +636,6 @@ bool VncConnection::initFrameBuffer( rfbClient* client )
 	m_imgLock.unlock();
 
 	// set up pixel format according to QImage
-	client->format.bitsPerPixel = 32;
 	client->format.redShift = 16;
 	client->format.greenShift = 8;
 	client->format.blueShift = 0;
@@ -682,16 +650,16 @@ bool VncConnection::initFrameBuffer( rfbClient* client )
 	client->appData.qualityLevel = 9;
 	client->appData.enableJPEG = false;
 
-	switch( quality() )
+	switch( m_quality )
 	{
-	case ScreenshotQuality:
+	case Quality::Screenshot:
 		// make sure to use lossless raw encoding
 		client->appData.encodingsString = "raw";
 		break;
-	case RemoteControlQuality:
+	case Quality::RemoteControl:
 		client->appData.useRemoteCursor = true;
 		break;
-	case ThumbnailQuality:
+	case Quality::Thumbnail:
 		client->appData.compressLevel = 9;
 		client->appData.qualityLevel = 5;
 		client->appData.enableJPEG = true;
@@ -700,7 +668,7 @@ bool VncConnection::initFrameBuffer( rfbClient* client )
 		break;
 	}
 
-	m_framebufferState = FramebufferInitialized;
+	m_framebufferState = FramebufferState::Initialized;
 
 	emit framebufferSizeChanged( client->width, client->height );
 
@@ -711,27 +679,28 @@ bool VncConnection::initFrameBuffer( rfbClient* client )
 
 void VncConnection::finishFrameBufferUpdate()
 {
-	m_framebufferState = FramebufferValid;
-	setControlFlag( ScaledScreenNeedsUpdate, true );
+	m_framebufferUpdateWatchdog.restart();
+
+	m_framebufferState = FramebufferState::Valid;
+	setControlFlag( ControlFlag::ScaledScreenNeedsUpdate, true );
 
 	emit framebufferUpdateComplete();
-
 }
 
 
 
 void VncConnection::sendEvents()
 {
-	m_globalMutex.lock();
+	m_eventQueueMutex.lock();
 
 	while( m_eventQueue.isEmpty() == false )
 	{
 		auto event = m_eventQueue.dequeue();
 
 		// unlock the queue mutex during the runtime of ClientEvent::fire()
-		m_globalMutex.unlock();
+		m_eventQueueMutex.unlock();
 
-		if( isControlFlagSet( TerminateThread ) == false )
+		if( isControlFlagSet( ControlFlag::TerminateThread ) == false )
 		{
 			event->fire( m_client );
 		}
@@ -739,228 +708,74 @@ void VncConnection::sendEvents()
 		delete event;
 
 		// and lock it again
-		m_globalMutex.lock();
+		m_eventQueueMutex.lock();
 	}
 
-	m_globalMutex.unlock();
+	m_eventQueueMutex.unlock();
 }
 
 
 
-void VncConnection::enqueueEvent( MessageEvent* event)
+void VncConnection::enqueueEvent( VncEvent* event, bool wake )
 {
-	QMutexLocker lock( &m_globalMutex );
-	if( m_state != Connected )
+	if( state() != State::Connected )
 	{
 		return;
 	}
 
+	m_eventQueueMutex.lock();
 	m_eventQueue.enqueue( event );
+	m_eventQueueMutex.unlock();
+
+	if( wake )
+	{
+		m_updateIntervalSleeper.wakeAll();
+	}
+}
+
+
+
+bool VncConnection::isEventQueueEmpty()
+{
+	QMutexLocker lock( &m_eventQueueMutex );
+	return m_eventQueue.isEmpty();
 }
 
 
 
 void VncConnection::mouseEvent( int x, int y, int buttonMask )
 {
-	enqueueEvent( new PointerClientEvent( x, y, buttonMask ) );
+	enqueueEvent( new VncPointerEvent( x, y, buttonMask ), true );
 }
 
 
 
 void VncConnection::keyEvent( unsigned int key, bool pressed )
 {
-	enqueueEvent( new KeyClientEvent( key, pressed ) );
+	enqueueEvent( new VncKeyEvent( key, pressed ), true );
 }
 
 
 
 void VncConnection::clientCut( const QString& text )
 {
-	enqueueEvent( new ClientCutEvent( text ) );
-}
-
-
-
-void VncConnection::handleSecTypeVeyon( rfbClient* client )
-{
-	auto connection = static_cast<VncConnection *>( clientData( client, VncConnectionTag ) );
-	if( connection == nullptr )
-	{
-		return;
-	}
-
-	SocketDevice socketDevice( libvncClientDispatcher, client );
-	VariantArrayMessage message( &socketDevice );
-	message.receive();
-
-	int authTypeCount = message.read().toInt();
-
-	QList<RfbVeyonAuth::Type> authTypes;
-	authTypes.reserve( authTypeCount );
-
-	for( int i = 0; i < authTypeCount; ++i )
-	{
-#if QT_VERSION < 0x050600
-#warning Building legacy compat code for unsupported version of Qt
-		authTypes.append( static_cast<RfbVeyonAuth::Type>( message.read().toInt() ) );
-#else
-		authTypes.append( message.read().value<RfbVeyonAuth::Type>() );
-#endif
-	}
-
-	qDebug() << Q_FUNC_INFO << QThread::currentThreadId() << "received authentication types:" << authTypes;
-
-	RfbVeyonAuth::Type chosenAuthType = RfbVeyonAuth::Token;
-	if( authTypes.count() > 0 )
-	{
-		chosenAuthType = authTypes.first();
-
-		// look whether the VncConnection recommends a specific
-		// authentication type (e.g. VeyonAuthHostBased when running as
-		// demo client)
-
-		for( auto authType : authTypes )
-		{
-			if( connection->veyonAuthType() == authType )
-			{
-				chosenAuthType = authType;
-			}
-		}
-	}
-
-	qDebug() << Q_FUNC_INFO << QThread::currentThreadId() << "chose authentication type:" << authTypes;
-
-	VariantArrayMessage authReplyMessage( &socketDevice );
-
-	authReplyMessage.write( chosenAuthType );
-
-	// send username which is used when displaying an access confirm dialog
-	if( VeyonCore::authenticationCredentials().hasCredentials( AuthenticationCredentials::UserLogon ) )
-	{
-		authReplyMessage.write( VeyonCore::authenticationCredentials().logonUsername() );
-	}
-	else
-	{
-		authReplyMessage.write( VeyonCore::platform().userFunctions().currentUser() );
-	}
-
-	authReplyMessage.send();
-
-	VariantArrayMessage authAckMessage( &socketDevice );
-	authAckMessage.receive();
-
-	switch( chosenAuthType )
-	{
-	case RfbVeyonAuth::KeyFile:
-		if( VeyonCore::authenticationCredentials().hasCredentials( AuthenticationCredentials::PrivateKey ) )
-		{
-			VariantArrayMessage challengeReceiveMessage( &socketDevice );
-			challengeReceiveMessage.receive();
-			const auto challenge = challengeReceiveMessage.read().toByteArray();
-
-			if( challenge.size() != CryptoCore::ChallengeSize )
-			{
-				qCritical() << Q_FUNC_INFO << QThread::currentThreadId() << "challenge size mismatch!";
-				break;
-			}
-
-			// create local copy of private key so we can modify it within our own thread
-			auto key = VeyonCore::authenticationCredentials().privateKey();
-			if( key.isNull() || key.canSign() == false )
-			{
-				qCritical() << Q_FUNC_INFO << QThread::currentThreadId() << "invalid private key!";
-				break;
-			}
-
-			const auto signature = key.signMessage( challenge, CryptoCore::DefaultSignatureAlgorithm );
-
-			VariantArrayMessage challengeResponseMessage( &socketDevice );
-			challengeResponseMessage.write( VeyonCore::instance()->authenticationKeyName() );
-			challengeResponseMessage.write( signature );
-			challengeResponseMessage.send();
-		}
-		break;
-
-	case RfbVeyonAuth::HostWhiteList:
-		// nothing to do - we just get accepted because the host white list contains our IP
-		break;
-
-	case RfbVeyonAuth::Logon:
-	{
-		VariantArrayMessage publicKeyMessage( &socketDevice );
-		publicKeyMessage.receive();
-
-		CryptoCore::PublicKey publicKey = CryptoCore::PublicKey::fromPEM( publicKeyMessage.read().toString() );
-
-		if( publicKey.canEncrypt() == false )
-		{
-			qCritical() << Q_FUNC_INFO << QThread::currentThreadId() << "can't encrypt with given public key!";
-			break;
-		}
-
-		CryptoCore::SecureArray plainTextPassword( VeyonCore::authenticationCredentials().logonPassword().toUtf8() );
-		CryptoCore::SecureArray encryptedPassword = publicKey.encrypt( plainTextPassword, CryptoCore::DefaultEncryptionAlgorithm );
-		if( encryptedPassword.isEmpty() )
-		{
-			qCritical() << Q_FUNC_INFO << QThread::currentThreadId() << "password encryption failed!";
-			break;
-		}
-
-		VariantArrayMessage passwordResponse( &socketDevice );
-		passwordResponse.write( encryptedPassword.toByteArray() );
-		passwordResponse.send();
-		break;
-	}
-
-	case RfbVeyonAuth::Token:
-	{
-		VariantArrayMessage tokenAuthMessage( &socketDevice );
-		tokenAuthMessage.write( VeyonCore::authenticationCredentials().token() );
-		tokenAuthMessage.send();
-		break;
-	}
-
-	default:
-		// nothing to do - we just get accepted
-		break;
-	}
-}
-
-
-
-void VncConnection::hookPrepareAuthentication( rfbClient* client )
-{
-	auto connection = static_cast<VncConnection *>( clientData( client, VncConnectionTag ) );
-	if( connection )
-	{
-		// set our internal flag which indicates that we basically have communication with the client
-		// which means that the host is reachable
-		connection->setControlFlag( ServerReachable, true );
-	}
+	enqueueEvent( new VncClientCutEvent( text ), true );
 }
 
 
 
 qint64 VncConnection::libvncClientDispatcher( char* buffer, const qint64 bytes,
-												   SocketDevice::SocketOperation operation, void* user )
+											  SocketDevice::SocketOperation operation, void* user )
 {
-	rfbClient* client = static_cast<rfbClient *>( user );
+	auto client = static_cast<rfbClient *>( user );
 	switch( operation )
 	{
 	case SocketDevice::SocketOpRead:
-		return ReadFromRFBServer( client, buffer, bytes ) ? bytes : 0;
+		return ReadFromRFBServer( client, buffer, static_cast<unsigned int>( bytes ) ) ? bytes : 0;
 
 	case SocketDevice::SocketOpWrite:
-		return WriteToRFBServer( client, buffer, bytes ) ? bytes : 0;
+		return WriteToRFBServer( client, buffer, static_cast<unsigned int>( bytes ) ) ? bytes : 0;
 	}
 
 	return 0;
 }
-
-
-
-void handleSecTypeVeyon( rfbClient *client )
-{
-	VncConnection::hookPrepareAuthentication( client );
-	VncConnection::handleSecTypeVeyon( client );
-}
