@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef COMPUTER_CONTROL_LIST_MODEL_H
-#define COMPUTER_CONTROL_LIST_MODEL_H
+#pragma once
 
 #include <QAbstractListModel>
 #include <QImage>
@@ -45,10 +44,17 @@ public:
 		DisplayUserAndComputerName,
 		DisplayUserName,
 		DisplayComputerName,
-		DisplayRoleContentCount
 	};
+	Q_ENUM(DisplayRoleContent)
 
-	ComputerControlListModel( VeyonMaster* masterCore, QObject* parent = nullptr );
+	enum SortOrder {
+		SortByComputerAndUserName,
+		SortByUserName,
+		SortByComputerName,
+	};
+	Q_ENUM(SortOrder)
+
+	explicit ComputerControlListModel( VeyonMaster* masterCore, QObject* parent = nullptr );
 
 	int rowCount( const QModelIndex& parent = QModelIndex() ) const override;
 
@@ -68,19 +74,19 @@ public:
 	Qt::DropActions supportedDragActions() const override;
 	Qt::DropActions supportedDropActions() const override;
 
-
-public slots:
 	void reload();
 
 signals:
 	void activeFeaturesChanged( QModelIndex );
 
-private slots:
+private:
 	void update();
 
-	void updateComputerScreens();
+	void updateState( const QModelIndex& index );
+	void updateScreen( const QModelIndex& index );
+	void updateActiveFeatures( const QModelIndex& index );
+	void updateUser( const QModelIndex& index );
 
-private:
 	void startComputerControlInterface( const ComputerControlInterface::Pointer& controlInterface, const QModelIndex& index );
 	void stopComputerControlInterface( const ComputerControlInterface::Pointer& controlInterface );
 
@@ -91,6 +97,7 @@ private:
 	QImage computerDecorationRole( const ComputerControlInterface::Pointer& controlInterface ) const;
 	QString computerToolTipRole( const ComputerControlInterface::Pointer& controlInterface ) const;
 	QString computerDisplayRole( const ComputerControlInterface::Pointer& controlInterface ) const;
+	QString computerSortRole( const ComputerControlInterface::Pointer& controlInterface ) const;
 	static QString computerStateDescription( const ComputerControlInterface::Pointer& controlInterface );
 	static QString loggedOnUserInformation( const ComputerControlInterface::Pointer& controlInterface );
 	QString activeFeatures( const ComputerControlInterface::Pointer& controlInterface ) const;
@@ -98,6 +105,7 @@ private:
 	VeyonMaster* m_master;
 
 	DisplayRoleContent m_displayRoleContent;
+	SortOrder m_sortOrder;
 
 	QImage m_iconDefault;
 	QImage m_iconConnectionProblem;
@@ -106,5 +114,3 @@ private:
 	ComputerControlInterfaceList m_computerControlInterfaces;
 
 };
-
-#endif // COMPUTER_LIST_MODEL_H
