@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef COMPUTER_MANAGER_H
-#define COMPUTER_MANAGER_H
+#pragma once
 
 #include "CheckableItemProxyModel.h"
 #include "ComputerControlInterface.h"
@@ -53,8 +52,8 @@ public:
 
 	ComputerList selectedComputers( const QModelIndex& parent );
 
-	void addRoom( const QString& room );
-	void removeRoom( const QString& room );
+	void addLocation( const QString& location );
+	void removeLocation( const QString& location );
 
 	bool saveComputerAndUsersList( const QString& fileName );
 
@@ -64,24 +63,23 @@ signals:
 	void computerSelectionReset();
 	void computerSelectionChanged();
 
-private slots:
+private:
 	void checkChangedData( const QModelIndex& topLeft, const QModelIndex& bottomRight, const QVector<int>& roles );
 
-private:
-	void initRooms();
+	void initLocations();
 	void initNetworkObjectLayer();
 	void initComputerTreeModel();
-	void updateRoomFilterList();
+	void updateLocationFilterList();
 
-	QString findRoomOfComputer( const QStringList& hostNames, const QList<QHostAddress>& hostAddresses, const QModelIndex& parent );
+	QString findLocationOfComputer( const QStringList& hostNames, const QList<QHostAddress>& hostAddresses, const QModelIndex& parent );
 
-	ComputerList getComputersInRoom( const QString& roomName, const QModelIndex& parent = QModelIndex() );
+	ComputerList getComputersAtLocation( const QString& locationName, const QModelIndex& parent = QModelIndex() );
 
 	QModelIndex findNetworkObject( NetworkObject::Uid networkObjectUid, const QModelIndex& parent = QModelIndex() );
 
 	QModelIndex mapToUserNameModelIndex( const QModelIndex& networkObjectIndex );
 
-	static const int OverlayDataColumnUsername = 1;
+	static constexpr int OverlayDataUsernameColumn = 1;
 
 	UserConfig& m_config;
 
@@ -91,12 +89,10 @@ private:
 	CheckableItemProxyModel* m_computerTreeModel;
 	NetworkObjectFilterProxyModel* m_networkObjectFilterProxyModel;
 
-	QStringList m_currentRooms;
-	QStringList m_roomFilterList;
+	QStringList m_currentLocations;
+	QStringList m_locationFilterList;
 
 	QStringList m_localHostNames;
 	QList<QHostAddress> m_localHostAddresses;
 
 };
-
-#endif // COMPUTER_MANAGER_H
