@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2007-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,8 +21,7 @@
  * USA.
  */
 
-#ifndef MAIN_TOOL_BAR_H
-#define MAIN_TOOL_BAR_H
+#pragma once
 
 #include <QToolBar>
 
@@ -32,21 +31,17 @@ class MainToolBar : public QToolBar
 {
 	Q_OBJECT
 public:
-	MainToolBar( QWidget* parent );
-	~MainToolBar() override;
-
-
-private slots:
-	void toggleToolTips();
-	void toggleIconMode();
+	explicit MainToolBar( QWidget* parent );
+	~MainToolBar() override = default;
 
 
 private:
+	void toggleToolTips();
+	void toggleIconMode();
+
 	void contextMenuEvent( QContextMenuEvent* event ) override;
 	void paintEvent( QPaintEvent* event ) override;
 
 	MainWindow* m_mainWindow;
 
 } ;
-
-#endif
