@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2004-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -36,8 +36,8 @@
 #include "AuthenticationCredentials.h"
 #include "ComputerControlListModel.h"
 #include "ComputerManager.h"
-#include "ComputerManagementView.h"
-#include "ScreenshotManagementView.h"
+#include "ComputerSelectPanel.h"
+#include "ScreenshotManagementPanel.h"
 #include "FeatureManager.h"
 #include "MonitoringMode.h"
 #include "NetworkObjectDirectory.h"
@@ -63,11 +63,11 @@ MainWindow::MainWindow( VeyonMaster &masterCore, QWidget* parent ) :
 	restoreState( QByteArray::fromBase64( m_master.userConfig().windowState().toUtf8() ) );
 	restoreGeometry( QByteArray::fromBase64( m_master.userConfig().windowGeometry().toUtf8() ) );
 
-	ui->computerMonitoringView->setVeyonMaster( m_master );
+	ui->computerMonitoringWidget->setVeyonMaster( m_master );
 
 	// add widgets to status bar
-	ui->statusBar->addWidget( ui->computerManagementButton );
-	ui->statusBar->addWidget( ui->screenshotManagementButton );
+	ui->statusBar->addWidget( ui->computerSelectPanelButton );
+	ui->statusBar->addWidget( ui->screenshotManagementPanelButton );
 	ui->statusBar->addWidget( ui->spacerLabel1 );
 	ui->statusBar->addWidget( ui->filterLineEdit, 2 );
 	ui->statusBar->addWidget( ui->filterPoweredOnComputersButton );
@@ -75,7 +75,7 @@ MainWindow::MainWindow( VeyonMaster &masterCore, QWidget* parent ) :
 	ui->statusBar->addWidget( ui->gridSizeSlider, 2 );
 	ui->statusBar->addWidget( ui->autoFitButton );
 	ui->statusBar->addWidget( ui->spacerLabel3 );
-	ui->statusBar->addWidget( ui->useCustomComputerPlacementButton );
+	ui->statusBar->addWidget( ui->useCustomComputerArrangementButton );
 	ui->statusBar->addWidget( ui->alignComputersButton );
 	ui->statusBar->addWidget( ui->spacerLabel4 );
 	ui->statusBar->addWidget( ui->aboutButton );
@@ -86,60 +86,60 @@ MainWindow::MainWindow( VeyonMaster &masterCore, QWidget* parent ) :
 
 	ui->centralLayout->addWidget( splitter );
 
-	m_computerManagementView = new ComputerManagementView( m_master.computerManager(), splitter );
-	m_screenshotManagementView = new ScreenshotManagementView( splitter );
+	m_computerSelectPanel = new ComputerSelectPanel( m_master.computerManager(), splitter );
+	m_screenshotManagementPanel = new ScreenshotManagementPanel( splitter );
 
-	splitter->addWidget( m_computerManagementView );
-	splitter->addWidget( m_screenshotManagementView );
-	splitter->addWidget( ui->computerMonitoringView );
+	splitter->addWidget( m_computerSelectPanel );
+	splitter->addWidget( m_screenshotManagementPanel );
+	splitter->addWidget( ui->computerMonitoringWidget );
 
 	// hide views per default and connect related button
-	m_computerManagementView->hide();
-	m_screenshotManagementView->hide();
+	m_computerSelectPanel->hide();
+	m_screenshotManagementPanel->hide();
 
-	connect( ui->computerManagementButton, &QAbstractButton::toggled,
-			 m_computerManagementView, &QWidget::setVisible );
-	connect( ui->screenshotManagementButton, &QAbstractButton::toggled,
-			 m_screenshotManagementView, &QWidget::setVisible );
+	connect( ui->computerSelectPanelButton, &QAbstractButton::toggled,
+			 m_computerSelectPanel, &QWidget::setVisible );
+	connect( ui->screenshotManagementPanelButton, &QAbstractButton::toggled,
+			 m_screenshotManagementPanel, &QWidget::setVisible );
 
-	if( VeyonCore::config().openComputerManagementAtStart() )
+	if( VeyonCore::config().autoOpenComputerSelectPanel() )
 	{
-		ui->computerManagementButton->setChecked( true );
+		ui->computerSelectPanelButton->setChecked( true );
 	}
 
 	// initialize search filter
 	ui->filterPoweredOnComputersButton->setChecked( m_master.userConfig().filterPoweredOnComputers() );
 	connect( ui->filterLineEdit, &QLineEdit::textChanged,
-			 ui->computerMonitoringView, &ComputerMonitoringView::setSearchFilter );
+			 ui->computerMonitoringWidget, &ComputerMonitoringWidget::setSearchFilter );
 	connect( ui->filterPoweredOnComputersButton, &QToolButton::toggled,
-			 ui->computerMonitoringView, &ComputerMonitoringView::setFilterPoweredOnComputers );
+			 ui->computerMonitoringWidget, &ComputerMonitoringWidget::setFilterPoweredOnComputers );
 
 	// initialize monitoring screen size slider
-	ui->gridSizeSlider->setMinimum( ComputerMonitoringView::MinimumComputerScreenSize );
-	ui->gridSizeSlider->setMaximum( ComputerMonitoringView::MaximumComputerScreenSize );
+	ui->gridSizeSlider->setMinimum( ComputerMonitoringWidget::MinimumComputerScreenSize );
+	ui->gridSizeSlider->setMaximum( ComputerMonitoringWidget::MaximumComputerScreenSize );
 
 	connect( ui->gridSizeSlider, &QSlider::valueChanged,
-			 ui->computerMonitoringView, &ComputerMonitoringView::setComputerScreenSize );
-	connect( ui->computerMonitoringView, &ComputerMonitoringView::computerScreenSizeAdjusted,
+			 ui->computerMonitoringWidget, &ComputerMonitoringWidget::setComputerScreenSize );
+	connect( ui->computerMonitoringWidget, &ComputerMonitoringWidget::computerScreenSizeAdjusted,
 			 ui->gridSizeSlider, &QSlider::setValue );
 	connect( ui->autoFitButton, &QToolButton::clicked,
-			 ui->computerMonitoringView, &ComputerMonitoringView::autoAdjustComputerScreenSize );
+			 ui->computerMonitoringWidget, &ComputerMonitoringWidget::autoAdjustComputerScreenSize );
 
-	int size = ComputerMonitoringView::DefaultComputerScreenSize;
-	if( m_master.userConfig().monitoringScreenSize() >= ComputerMonitoringView::MinimumComputerScreenSize )
+	int size = ComputerMonitoringWidget::DefaultComputerScreenSize;
+	if( m_master.userConfig().monitoringScreenSize() >= ComputerMonitoringWidget::MinimumComputerScreenSize )
 	{
 		size = m_master.userConfig().monitoringScreenSize();
 	}
 
 	ui->gridSizeSlider->setValue( size );
-	ui->computerMonitoringView->setComputerScreenSize( size );
+	ui->computerMonitoringWidget->setComputerScreenSize( size );
 
 	// initialize computer placement controls
-	ui->useCustomComputerPlacementButton->setChecked( m_master.userConfig().useCustomComputerPositions() );
-	connect( ui->useCustomComputerPlacementButton, &QToolButton::toggled,
-			 ui->computerMonitoringView, &ComputerMonitoringView::setUseCustomComputerPositions );
+	ui->useCustomComputerArrangementButton->setChecked( m_master.userConfig().useCustomComputerPositions() );
+	connect( ui->useCustomComputerArrangementButton, &QToolButton::toggled,
+			 ui->computerMonitoringWidget, &ComputerMonitoringWidget::setUseCustomComputerPositions );
 	connect( ui->alignComputersButton, &QToolButton::clicked,
-			 ui->computerMonitoringView, &ComputerMonitoringView::alignComputers );
+			 ui->computerMonitoringWidget, &ComputerMonitoringWidget::alignComputers );
 
 
 	// create the main toolbar
@@ -149,14 +149,9 @@ MainWindow::MainWindow( VeyonMaster &masterCore, QWidget* parent ) :
 	addToolBar( Qt::TopToolBarArea, ui->toolBar );
 
 	addFeaturesToToolBar();
+	reloadSubFeatures();
 
-	m_modeGroup->button( qHash( m_master.builtinFeatures().monitoringMode().feature().uid() ) )->setChecked( true );
-
-	// setup system tray icon
-	QIcon icon( QStringLiteral(":/resources/icon16.png") );
-	icon.addFile( QStringLiteral(":/resources/icon22.png") );
-	icon.addFile( QStringLiteral(":/resources/icon32.png") );
-	icon.addFile( QStringLiteral(":/resources/icon64.png") );
+	m_modeGroup->button( static_cast<int>( qHash( VeyonCore::builtinFeatures().monitoringMode().feature().uid() ) ) )->setChecked( true );
 
 	VeyonCore::enforceBranding( this );
 }
@@ -172,24 +167,22 @@ MainWindow::~MainWindow()
 
 bool MainWindow::initAuthentication()
 {
-	if( VeyonCore::instance()->initAuthentication( AuthenticationCredentials::AllTypes ) )
+	if( VeyonCore::instance()->initAuthentication() )
 	{
 		return true;
 	}
 
-	// if we have logon credentials, assume they are fine and continue
-	if( VeyonCore::authenticationCredentials().hasCredentials( AuthenticationCredentials::UserLogon ) )
+	if( VeyonCore::config().authenticationMethod() == VeyonCore::AuthenticationMethod::KeyFileAuthentication )
 	{
-		return true;
-	}
+		QMessageBox::information( nullptr,
+				tr( "Authentication impossible" ),
+				tr(	"No authentication key files were found or your current ones "
+					"are outdated. Please create new key files using the %1 "
+					"Configurator. Alternatively set up logon authentication "
+					"using the %1 Configurator. Otherwise you won't be "
+					"able to access computers using %1." ).arg( VeyonCore::applicationName() ) );
 
-	QMessageBox::information( nullptr,
-			tr( "Authentication impossible" ),
-			tr(	"No authentication key files were found or your current ones "
-				"are outdated. Please create new key files using the %1 "
-				"Configurator. Alternatively set up logon authentication "
-				"using the %1 Configurator. Otherwise you won't be "
-				"able to access computers using %1." ).arg( VeyonCore::applicationName() ) );
+	}
 
 	return false;
 }
@@ -199,16 +192,15 @@ bool MainWindow::initAuthentication()
 bool MainWindow::initAccessControl()
 {
 	if( VeyonCore::config().accessControlForMasterEnabled() &&
-			VeyonCore::authenticationCredentials().hasCredentials( AuthenticationCredentials::UserLogon ) )
+			VeyonCore::authenticationCredentials().hasCredentials( AuthenticationCredentials::Type::UserLogon ) )
 	{
 		const auto accessControlResult =
 				AccessControlProvider().checkAccess( VeyonCore::authenticationCredentials().logonUsername(),
 													 QHostAddress( QHostAddress::LocalHost ).toString(),
 													 QStringList() );
-		if( accessControlResult == AccessControlProvider::AccessDeny )
+		if( accessControlResult == AccessControlProvider::Access::Deny )
 		{
-			qWarning() << "MainWindow::initAccessControl(): user"
-					   << VeyonCore::authenticationCredentials().logonUsername()
+			vWarning() << "user" << VeyonCore::authenticationCredentials().logonUsername()
 					   << "is not allowed to access computers";
 			QMessageBox::critical( nullptr, tr( "Access denied" ),
 								   tr( "According to the local configuration you're not allowed "
@@ -223,9 +215,23 @@ bool MainWindow::initAccessControl()
 
 
 
+void MainWindow::reloadSubFeatures()
+{
+	for( const auto& feature : m_master.features() )
+	{
+		auto button = ui->toolBar->findChild<QToolButton *>( feature.name() );
+		if( button )
+		{
+			addSubFeaturesToToolButton( button, feature );
+		}
+	}
+}
+
+
+
 void MainWindow::closeEvent( QCloseEvent* event )
 {
-	if( m_master.currentMode() != m_master.builtinFeatures().monitoringMode().feature().uid() )
+	if( m_master.currentMode() != VeyonCore::builtinFeatures().monitoringMode().feature().uid() )
 	{
 		const Feature& activeFeature = m_master.featureManager().feature( m_master.currentMode() );
 
@@ -236,8 +242,8 @@ void MainWindow::closeEvent( QCloseEvent* event )
 		return;
 	}
 
-	m_master.userConfig().setWindowState( saveState().toBase64() );
-	m_master.userConfig().setWindowGeometry( saveGeometry().toBase64() );
+	m_master.userConfig().setWindowState( QString::fromLatin1( saveState().toBase64() ) );
+	m_master.userConfig().setWindowGeometry( QString::fromLatin1( saveGeometry().toBase64() ) );
 
 	QMainWindow::closeEvent( event );
 }
@@ -285,23 +291,29 @@ void MainWindow::addFeaturesToToolBar()
 			m_master.runFeature( feature );
 			updateModeButtonGroup();
 		} );
+		btn->setObjectName( feature.name() );
 		btn->addTo( ui->toolBar );
 
 		if( feature.testFlag( Feature::Mode ) )
 		{
 			btn->setCheckable( true );
-			m_modeGroup->addButton( btn, qHash( feature.uid() ) );
+			m_modeGroup->addButton( btn, buttonId( feature ) );
 		}
-
-		addSubFeaturesToToolButton( btn, feature.uid() );
 	}
 }
 
 
 
-void MainWindow::addSubFeaturesToToolButton( ToolButton* button, Feature::Uid parentFeatureUid )
+void MainWindow::addSubFeaturesToToolButton( QToolButton* button, const Feature& parentFeature )
 {
-	const auto subFeatures = m_master.subFeatures( parentFeatureUid );
+	if( button->menu() )
+	{
+		button->menu()->close();
+		button->menu()->deleteLater();
+		button->setMenu( nullptr );
+	}
+
+	const auto subFeatures = m_master.subFeatures( parentFeature.uid() );
 
 	if( subFeatures.isEmpty() )
 	{
@@ -309,6 +321,8 @@ void MainWindow::addSubFeaturesToToolButton( ToolButton* button, Feature::Uid pa
 	}
 
 	auto menu = new QMenu( button );
+	menu->setObjectName( parentFeature.name() );
+	menu->setToolTipsVisible( true );
 
 	for( const auto& subFeature : subFeatures )
 	{
@@ -318,9 +332,11 @@ void MainWindow::addSubFeaturesToToolButton( ToolButton* button, Feature::Uid pa
 		action->setShortcut( subFeature.shortcut() );
 		connect( action, &QAction::triggered, this, [=] () { m_master.runFeature( subFeature ); } );
 #else
-		menu->addAction( QIcon( subFeature.iconUrl() ), subFeature.displayName(), this,
-						 [=]() { m_master.runFeature( subFeature ); }, subFeature.shortcut() );
+		auto action = menu->addAction( QIcon( subFeature.iconUrl() ), subFeature.displayName(), this,
+									   [=]() { m_master.runFeature( subFeature ); }, subFeature.shortcut() );
 #endif
+		action->setToolTip( subFeature.description() );
+		action->setObjectName( subFeature.uid().toString() );
 	}
 
 	button->setMenu( menu );
@@ -331,10 +347,10 @@ void MainWindow::addSubFeaturesToToolButton( ToolButton* button, Feature::Uid pa
 
 void MainWindow::updateModeButtonGroup()
 {
-	const Feature::Uid& monitoringMode = m_master.builtinFeatures().monitoringMode().feature().uid();
+	const auto& monitoringMode = VeyonCore::builtinFeatures().monitoringMode().feature();
 
-	if( m_master.currentMode() == monitoringMode )
+	if( m_master.currentMode() == monitoringMode.uid() )
 	{
-		m_modeGroup->button( qHash( monitoringMode ) )->setChecked( true );
+		m_modeGroup->button( buttonId( monitoringMode ) )->setChecked( true );
 	}
 }
