@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -25,12 +25,20 @@
 #include "NetworkObjectModel.h"
 #include "NetworkObjectFilterProxyModel.h"
 
+#if defined(QT_TESTLIB_LIB) && QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
+#include <QAbstractItemModelTester>
+#endif
+
+
 NetworkObjectFilterProxyModel::NetworkObjectFilterProxyModel( QObject* parent ) :
 	QSortFilterProxyModel( parent ),
 	m_groupList(),
 	m_computerExcludeList(),
 	m_excludeEmptyGroups( false )
 {
+#if defined(QT_TESTLIB_LIB) && QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
+	new QAbstractItemModelTester( this, QAbstractItemModelTester::FailureReportingMode::Warning, this );
+#endif
 }
 
 
