@@ -1,9 +1,9 @@
 /*
- * RecursiveFilterProxyModel.cpp - proxy model for recursive filtering 
+ * RecursiveFilterProxyModel.cpp - proxy model for recursive filtering
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -24,30 +24,14 @@
 
 #include "RecursiveFilterProxyModel.h"
 
+#if defined(QT_TESTLIB_LIB) && QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
+#include <QAbstractItemModelTester>
+#endif
+
 RecursiveFilterProxyModel::RecursiveFilterProxyModel( QObject* parent ) :
-	QSortFilterProxyModel( parent )
+	KRecursiveFilterProxyModel( parent )
 {
-}
-
-
-
-bool RecursiveFilterProxyModel::filterAcceptsRow( int sourceRow, const QModelIndex& sourceParent ) const
-{
-	if( sourceParent.isValid() )
-	{
-		return QSortFilterProxyModel::filterAcceptsRow( sourceRow, sourceParent );
-	}
-
-	const auto rowIndex = sourceModel()->index( sourceRow, 0, sourceParent );
-	const auto rowCount = sourceModel()->rowCount( rowIndex );
-
-	for( int i = 0; i < rowCount; ++i )
-	{
-		if( filterAcceptsRow( i, rowIndex ) )
-		{
-			return true;
-		}
-	}
-
-	return false;
+#if defined(QT_TESTLIB_LIB) && QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
+	new QAbstractItemModelTester( this, QAbstractItemModelTester::FailureReportingMode::Warning, this );
+#endif
 }
