@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,19 +22,13 @@
  *
  */
 
-#ifndef RECURSIVE_FILTER_PROXY_MODEL_H
-#define RECURSIVE_FILTER_PROXY_MODEL_H
+#pragma once
 
-#include <QSortFilterProxyModel>
+#include "krecursivefilterproxymodel.h"
 
-class RecursiveFilterProxyModel : public QSortFilterProxyModel
+class RecursiveFilterProxyModel : public KRecursiveFilterProxyModel
 {
-	Q_OBJECT
 public:
-	RecursiveFilterProxyModel( QObject* parent = nullptr );
-
-	bool filterAcceptsRow( int sourceRow, const QModelIndex& sourceParent ) const override;
+	explicit RecursiveFilterProxyModel( QObject* parent );
 
 };
-
-#endif // RECURSIVE_FILTER_PROXY_MODEL_H
