@@ -4,7 +4,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -28,11 +28,9 @@
 #include "VeyonCore.h"
 #include "UserConfig.h"
 
-FOREACH_PERSONAL_CONFIG_PROPERTY(IMPLEMENT_CONFIG_SET_PROPERTY)
-
 
 UserConfig::UserConfig( Configuration::Store::Backend backend ) :
-	Configuration::Object( backend, Configuration::Store::User, Configuration::Object(), QStringLiteral("VeyonMaster") )
+	Configuration::Object( backend, Configuration::Store::User, QStringLiteral("VeyonMaster") )
 {
 	if( isStoreWritable() == false )
 	{
