@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -38,16 +38,15 @@
 
 
 VeyonMaster::VeyonMaster( QObject* parent ) :
-	QObject( parent ),
-	m_builtinFeatures( new BuiltinFeatures() ),
+	VeyonMasterInterface( parent ),
+	m_userConfig( new UserConfig( Configuration::Store::JsonFile ) ),
 	m_featureManager( new FeatureManager() ),
 	m_features( featureList() ),
-	m_userConfig( new UserConfig( Configuration::Store::JsonFile ) ),
 	m_computerManager( new ComputerManager( *m_userConfig, this ) ),
 	m_computerControlListModel( new ComputerControlListModel( this, this ) ),
 	m_computerSortFilterProxyModel( new ComputerSortFilterProxyModel( this ) ),
 	m_mainWindow( nullptr ),
-	m_currentMode( m_builtinFeatures->monitoringMode().feature().uid() )
+	m_currentMode( VeyonCore::builtinFeatures().monitoringMode().feature().uid() )
 {
 	if( VeyonCore::config().enforceSelectedModeForClients() )
 	{
@@ -60,7 +59,7 @@ VeyonMaster::VeyonMaster( QObject* parent ) :
 			 m_featureManager->handleFeatureMessage( *this, featureMessage, computerControlInterface );
 	} );
 
-	VeyonCore::localComputerControlInterface().start( QSize(), m_builtinFeatures );
+	VeyonCore::localComputerControlInterface().start( QSize() );
 
 	// attach computer list model to proxy model
 	m_computerSortFilterProxyModel->setSourceModel( m_computerControlListModel );
@@ -85,8 +84,6 @@ VeyonMaster::~VeyonMaster()
 	delete m_userConfig;
 
 	delete m_featureManager;
-
-	delete m_builtinFeatures;
 }
 
 
@@ -103,8 +100,9 @@ FeatureList VeyonMaster::subFeatures( Feature::Uid parentFeatureUid ) const
 		for( const auto& feature : m_featureManager->features( pluginUid ) )
 		{
 			if( feature.testFlag( Feature::Master ) &&
-					feature.parentUid() == parentFeatureUid &&
-					disabledFeatures.contains( parentFeatureUid.toString() ) == false )
+				feature.parentUid() == parentFeatureUid &&
+				disabledFeatures.contains( parentFeatureUid.toString() ) == false &&
+				disabledFeatures.contains( feature.uid().toString() ) == false )
 			{
 				features += feature;
 			}
@@ -123,11 +121,28 @@ QWidget* VeyonMaster::mainWindow()
 
 
 
+Configuration::Object* VeyonMaster::userConfigurationObject()
+{
+	return m_userConfig;
+}
+
+
+
+void VeyonMaster::reloadSubFeatures()
+{
+	m_mainWindow->reloadSubFeatures();
+}
+
+
+
 ComputerControlInterfaceList VeyonMaster::filteredComputerControlInterfaces()
 {
-	ComputerControlInterfaceList computerControlInterfaces;
+	const auto rowCount = m_computerSortFilterProxyModel->rowCount();
 
-	for( int i = 0; i < m_computerSortFilterProxyModel->rowCount(); ++i )
+	ComputerControlInterfaceList computerControlInterfaces;
+	computerControlInterfaces.reserve( rowCount );
+
+	for( int i = 0; i < rowCount; ++i )
 	{
 		const auto index = m_computerSortFilterProxyModel->index( i, 0 );
 		const auto sourceIndex = m_computerSortFilterProxyModel->mapToSource( index );
@@ -149,7 +164,7 @@ void VeyonMaster::runFeature( const Feature& feature )
 
 		if( m_currentMode == feature.uid() )
 		{
-			const Feature& monitoringModeFeature = m_builtinFeatures->monitoringMode().feature();
+			const Feature& monitoringModeFeature = VeyonCore::builtinFeatures().monitoringMode().feature();
 
 			m_featureManager->startFeature( *this, monitoringModeFeature, computerControlInterfaces );
 			m_currentMode = monitoringModeFeature.uid();
@@ -184,7 +199,7 @@ void VeyonMaster::enforceDesignatedMode( const QModelIndex& index )
 			}
 		}
 
-		if( designatedModeFeature != m_builtinFeatures->monitoringMode().feature() )
+		if( designatedModeFeature != VeyonCore::builtinFeatures().monitoringMode().feature() )
 		{
 			featureManager().startFeature( *this, designatedModeFeature, { controlInterface } );
 		}
