@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef MASTER_CORE_H
-#define MASTER_CORE_H
+#pragma once
 
 #include <QObject>
 
@@ -42,18 +41,13 @@ class FeatureManager;
 class MainWindow;
 class UserConfig;
 
-class VeyonMaster : public QObject, public VeyonMasterInterface
+class VeyonMaster : public VeyonMasterInterface
 {
 	Q_OBJECT
 public:
-	VeyonMaster( QObject* parent = nullptr );
+	explicit VeyonMaster( QObject* parent = nullptr );
 	~VeyonMaster() override;
 
-	BuiltinFeatures& builtinFeatures()
-	{
-		return *m_builtinFeatures;
-	}
-
 	FeatureManager& featureManager()
 	{
 		return *m_featureManager;
@@ -92,6 +86,8 @@ public:
 	}
 
 	QWidget* mainWindow() override;
+	Configuration::Object* userConfigurationObject() override;
+	void reloadSubFeatures() override;
 
 	ComputerControlInterfaceList filteredComputerControlInterfaces();
 
@@ -103,10 +99,9 @@ public slots:
 private:
 	FeatureList featureList() const;
 
-	BuiltinFeatures* m_builtinFeatures;
+	UserConfig* m_userConfig;
 	FeatureManager* m_featureManager;
 	const FeatureList m_features;
-	UserConfig* m_userConfig;
 	ComputerManager* m_computerManager;
 	ComputerControlListModel* m_computerControlListModel;
 	ComputerSortFilterProxyModel* m_computerSortFilterProxyModel;
@@ -116,5 +111,3 @@ private:
 	Feature::Uid m_currentMode;
 
 } ;
-
-#endif
