@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -44,6 +44,8 @@ AuthKeysConfigurationPage::AuthKeysConfigurationPage() :
 {
 	ui->setupUi(this);
 
+	Configuration::UiMapping::setFlags( ui->keyFileDirectories, Configuration::Property::Flag::Advanced );
+
 #define CONNECT_BUTTON_SLOT(name) \
 			connect( ui->name, &QAbstractButton::clicked, this, &AuthKeysConfigurationPage::name );
 
@@ -127,7 +129,7 @@ void AuthKeysConfigurationPage::deleteKey()
 {
 	const auto title = ui->deleteKey->text();
 
-	const auto nameAndType = selectedKey().split('/');
+	const auto nameAndType = selectedKey().split(QLatin1Char('/'));
 
 	if( nameAndType.size() > 1 )
 	{
@@ -157,7 +159,7 @@ void AuthKeysConfigurationPage::importKey()
 {
 	const auto title = ui->importKey->text();
 
-	const auto inputFile = QFileDialog::getOpenFileName( this, title, QString(), m_keyFilesFilter );
+	const auto inputFile = QFileDialog::getOpenFileName( this, title, {}, m_keyFilesFilter );
 	if( inputFile.isEmpty() )
 	{
 		return;
@@ -187,7 +189,7 @@ void AuthKeysConfigurationPage::exportKey()
 {
 	const auto title = ui->exportKey->text();
 
-	const auto nameAndType = selectedKey().split('/');
+	const auto nameAndType = selectedKey().split(QLatin1Char('/'));
 
 	if( nameAndType.size() > 1 )
 	{
@@ -263,7 +265,7 @@ QString AuthKeysConfigurationPage::selectedKey() const
 		return m_authKeyTableModel.key( row );
 	}
 
-	return QString();
+	return {};
 }
 
 
