@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2018-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -48,12 +48,6 @@ AuthKeysManager::AuthKeysManager( QObject* parent ) :
 
 
 
-AuthKeysManager::~AuthKeysManager()
-{
-}
-
-
-
 bool AuthKeysManager::createKeyPair( const QString& name )
 {
 	if( VeyonCore::isAuthenticationKeyNameValid( name ) == false)
@@ -110,7 +104,7 @@ bool AuthKeysManager::deleteKey( const QString& name, const QString& type )
 
 	if( keyFile.remove() == false )
 	{
-		m_resultMessage = tr( "Could not remove key file \"%1\"!" ).arg( keyFileName ) + " " + m_checkPermissions;
+		m_resultMessage = tr( "Could not remove key file \"%1\"!" ).arg( keyFileName ) + QLatin1Char(' ') + m_checkPermissions;
 		return false;
 	}
 
@@ -120,7 +114,7 @@ bool AuthKeysManager::deleteKey( const QString& name, const QString& type )
 
 	if( keyFileBaseDirectory.rmdir( keyFileDirectory.dirName() ) == false )
 	{
-		m_resultMessage = tr( "Could not remove key file directory \"%1\"!" ).arg( keyFileDirectory.path() ) + " " + m_checkPermissions;
+		m_resultMessage = tr( "Could not remove key file directory \"%1\"!" ).arg( keyFileDirectory.path() ) + QLatin1Char(' ') + m_checkPermissions;
 		return false;
 	}
 
@@ -152,7 +146,7 @@ bool AuthKeysManager::exportKey( const QString& name, const QString& type, const
 
 	if( QFile::copy( keyFileName, outputFile ) == false )
 	{
-		m_resultMessage = tr( "Failed to write output file." ) + " " + m_checkPermissions;
+		m_resultMessage = tr( "Failed to write output file." ) + QLatin1Char(' ') + m_checkPermissions;
 		return false;
 	}
 
@@ -173,7 +167,7 @@ bool AuthKeysManager::importKey( const QString& name, const QString& type, const
 
 	if( QFileInfo( inputFile ).isReadable() == false )
 	{
-		m_resultMessage = tr( "Failed read input file." ) + " " + m_checkPermissions;
+		m_resultMessage = tr( "Failed read input file." ) + QLatin1Char(' ') + m_checkPermissions;
 		return false;
 	}
 
@@ -215,19 +209,19 @@ bool AuthKeysManager::importKey( const QString& name, const QString& type, const
 
 	if( VeyonCore::filesystem().ensurePathExists( QFileInfo( keyFileName ).path() ) == false )
 	{
-		m_resultMessage = tr( "Failed to create directory for key file." ) + " " + m_checkPermissions;
+		m_resultMessage = tr( "Failed to create directory for key file." ) + QLatin1Char(' ') + m_checkPermissions;
 		return false;
 	}
 
 	if( QFile::copy( inputFile, keyFileName ) == false )
 	{
-		m_resultMessage = tr( "Failed to write key file \"%1\"." ).arg( keyFileName ) + " " + m_checkPermissions;
+		m_resultMessage = tr( "Failed to write key file \"%1\"." ).arg( keyFileName ) + QLatin1Char(' ') + m_checkPermissions;
 		return false;
 	}
 
 	if( setKeyFilePermissions( name, type ) == false )
 	{
-		m_resultMessage = tr( "Failed to set permissions for key file \"%1\"!" ).arg( keyFileName ) + " " + m_checkPermissions;
+		m_resultMessage = tr( "Failed to set permissions for key file \"%1\"!" ).arg( keyFileName ) + QLatin1Char(' ') + m_checkPermissions;
 		return false;
 	}
 
@@ -312,19 +306,19 @@ bool AuthKeysManager::writePrivateKeyFile( const CryptoCore::PrivateKey& private
 {
 	if( VeyonCore::filesystem().ensurePathExists( QFileInfo( privateKeyFileName ).path() ) == false )
 	{
-		m_resultMessage = tr( "Failed to create directory for private key file \"%1\"." ).arg( privateKeyFileName) + " " + m_checkPermissions;
+		m_resultMessage = tr( "Failed to create directory for private key file \"%1\"." ).arg( privateKeyFileName) + QLatin1Char(' ') + m_checkPermissions;
 		return false;
 	}
 
 	if( privateKey.toPEMFile( privateKeyFileName ) == false )
 	{
-		m_resultMessage = tr( "Failed to save private key in file \"%1\"!" ).arg( privateKeyFileName ) + " " + m_checkPermissions;
+		m_resultMessage = tr( "Failed to save private key in file \"%1\"!" ).arg( privateKeyFileName ) + QLatin1Char(' ') + m_checkPermissions;
 		return false;
 	}
 
 	if( setPrivateKeyFilePermissions( privateKeyFileName ) == false )
 	{
-		m_resultMessage = tr( "Failed to set permissions for private key file \"%1\"!" ).arg( privateKeyFileName ) + " " + m_checkPermissions;
+		m_resultMessage = tr( "Failed to set permissions for private key file \"%1\"!" ).arg( privateKeyFileName ) + QLatin1Char(' ') + m_checkPermissions;
 		return false;
 	}
 
@@ -337,19 +331,19 @@ bool AuthKeysManager::writePublicKeyFile( const CryptoCore::PublicKey& publicKey
 {
 	if(	VeyonCore::filesystem().ensurePathExists( QFileInfo( publicKeyFileName ).path() ) == false )
 	{
-		m_resultMessage = tr( "Failed to create directory for public key file \"%1\"." ).arg( publicKeyFileName ) + " " + m_checkPermissions;
+		m_resultMessage = tr( "Failed to create directory for public key file \"%1\"." ).arg( publicKeyFileName ) + QLatin1Char(' ') + m_checkPermissions;
 		return false;
 	}
 
 	if( publicKey.toPEMFile( publicKeyFileName ) == false )
 	{
-		m_resultMessage = tr( "Failed to save public key in file \"%1\"!" ).arg( publicKeyFileName ) + " " + m_checkPermissions;
+		m_resultMessage = tr( "Failed to save public key in file \"%1\"!" ).arg( publicKeyFileName ) + QLatin1Char(' ') + m_checkPermissions;
 		return false;
 	}
 
 	if( setPublicKeyFilePermissions( publicKeyFileName ) == false )
 	{
-		m_resultMessage = tr( "Failed to set permissions for public key file \"%1\"!" ).arg( publicKeyFileName ) + " " + m_checkPermissions;
+		m_resultMessage = tr( "Failed to set permissions for public key file \"%1\"!" ).arg( publicKeyFileName ) + QLatin1Char(' ') + m_checkPermissions;
 		return false;
 	}
 
@@ -372,14 +366,14 @@ QString AuthKeysManager::detectKeyType( const QString& keyFile )
 		return m_keyTypePublic;
 	}
 
-	return QString();
+	return {};
 }
 
 
 
 bool AuthKeysManager::setAccessGroup( const QString& key, const QString& group )
 {
-	const auto nameAndType = key.split( '/' );
+	const auto nameAndType = key.split( QLatin1Char('/') );
 	const auto name = nameAndType.value( 0 );
 	const auto type = nameAndType.value( 1 );
 
@@ -393,14 +387,14 @@ bool AuthKeysManager::setAccessGroup( const QString& key, const QString& group )
 	if( VeyonCore::platform().filesystemFunctions().setFileOwnerGroup( keyFileName, group ) == false )
 	{
 		m_resultMessage = tr( "Failed to set owner of key file \"%1\" to \"%2\"." ).
-				arg( keyFileName, group ) + ' ' + m_checkPermissions;
+				arg( keyFileName, group ) + QLatin1Char(' ') + m_checkPermissions;
 		return false;
 	}
 
 	if( VeyonCore::platform().filesystemFunctions().
 			setFileOwnerGroupPermissions( keyFileName, QFile::ReadOwner | QFile::ReadGroup ) == false )
 	{
-		m_resultMessage = tr( "Failed to set permissions for key file \"%1\"." ).arg( keyFileName ) + ' ' + m_checkPermissions;
+		m_resultMessage = tr( "Failed to set permissions for key file \"%1\"." ).arg( keyFileName ) + QLatin1Char(' ') + m_checkPermissions;
 		return false;
 	}
 
@@ -413,13 +407,13 @@ bool AuthKeysManager::setAccessGroup( const QString& key, const QString& group )
 
 QString AuthKeysManager::accessGroup( const QString& key )
 {
-	const auto nameAndType = key.split( '/' );
+	const auto nameAndType = key.split( QLatin1Char('/') );
 	const auto name = nameAndType.value( 0 );
 	const auto type = nameAndType.value( 1 );
 
 	if( checkKey( name, type, false ) == false )
 	{
-		return QString();
+		return {};
 	}
 
 	return VeyonCore::platform().filesystemFunctions().fileOwnerGroup( keyFilePathFromType( name, type ) );
@@ -429,7 +423,7 @@ QString AuthKeysManager::accessGroup( const QString& key )
 
 QString AuthKeysManager::keyPairId( const QString& key )
 {
-	const auto nameAndType = key.split( '/' );
+	const auto nameAndType = key.split( QLatin1Char('/') );
 	const auto name = nameAndType.value( 0 );
 	const auto type = nameAndType.value( 1 );
 
@@ -473,7 +467,7 @@ QString AuthKeysManager::keyNameFromExportedKeyFile( const QString& keyFile )
 		return rx.cap( 1 );
 	}
 
-	return QString();
+	return {};
 }
 
 
@@ -504,7 +498,7 @@ bool AuthKeysManager::checkKey( const QString& name, const QString& type, bool c
 
 	if( checkIsReadable && keyFileInfo.isReadable() == false )
 	{
-		m_resultMessage = tr( "Failed to read key file." ) + " " + m_checkPermissions;
+		m_resultMessage = tr( "Failed to read key file." ) + QLatin1Char(' ') + m_checkPermissions;
 		return false;
 	}
 
@@ -524,7 +518,7 @@ QString AuthKeysManager::keyFilePathFromType( const QString& name, const QString
 		return VeyonCore::filesystem().publicKeyPath( name );
 	}
 
-	return QString();
+	return {};
 }
 
 
