@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2006-2013 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef DEMO_CLIENT_H
-#define DEMO_CLIENT_H
+#pragma once
 
 #include <QObject>
 
@@ -36,16 +35,11 @@ public:
 	DemoClient( const QString& host, bool fullscreen, QObject* parent = nullptr );
 	~DemoClient() override;
 
-
-private slots:
+private:
 	void viewDestroyed( QObject* obj );
 	void resizeToplevelWidget();
 
-
-private:
 	QWidget* m_toplevel;
 	VncView* m_vncView;
 
 } ;
-
-#endif
