@@ -29,18 +29,21 @@
 #include <QReadWriteLock>
 #include <QTimer>
 
-#include "VncClientProtocol.h"
+#include "CryptoCore.h"
 
 class DemoConfiguration;
 class QTcpServer;
+class QTcpSocket;
+class VncClientProtocol;
 
 class DemoServer : public QObject
 {
 	Q_OBJECT
 public:
+	using Password = CryptoCore::SecureArray;
 	using MessageList = QVector<QByteArray>;
 
-	DemoServer( int vncServerPort, const QString& vncServerPassword, const QString& demoAccessToken,
+	DemoServer( int vncServerPort, const Password& vncServerPassword, const Password& demoAccessToken,
 				const DemoConfiguration& configuration, QObject *parent );
 	~DemoServer() override;
 
@@ -49,10 +52,7 @@ public:
 		return m_configuration;
 	}
 
-	const QByteArray& serverInitMessage() const
-	{
-		return m_vncClientProtocol.serverInitMessage();
-	}
+	const QByteArray& serverInitMessage() const;
 
 	void lockDataForRead();
 
@@ -90,11 +90,11 @@ private:
 	const qint64 m_memoryLimit;
 	const int m_keyFrameInterval;
 	const int m_vncServerPort;
-	const QString m_demoAccessToken;
+	const Password m_demoAccessToken;
 
 	QTcpServer* m_tcpServer;
 	QTcpSocket* m_vncServerSocket;
-	VncClientProtocol m_vncClientProtocol;
+	VncClientProtocol* m_vncClientProtocol;
 
 	QReadWriteLock m_dataLock;
 	QTimer m_framebufferUpdateTimer;
