@@ -20,8 +20,7 @@
  *
  */
 
-#ifndef RUN_PROGRAM_DIALOG_H
-#define RUN_PROGRAM_DIALOG_H
+#pragma once
 
 #include <QDialog>
 
@@ -31,21 +30,31 @@ class RunProgramDialog : public QDialog
 {
 	Q_OBJECT
 public:
-	RunProgramDialog( QWidget *parent );
+	explicit RunProgramDialog( QWidget *parent );
 	~RunProgramDialog() override;
 
-	const QStringList& programs() const
+	const QString& programs() const
 	{
 		return m_programs;
 	}
 
-private slots:
-	void accept() override;
+	bool remember() const
+	{
+		return m_remember;
+	}
+
+	const QString& presetName() const
+	{
+		return m_presetName;
+	}
 
 private:
+	void validate();
+	void accept() override;
+
 	Ui::RunProgramDialog* ui;
-	QStringList m_programs;
+	QString m_programs;
+	bool m_remember;
+	QString m_presetName;
 
 } ;
-
-#endif
