@@ -221,12 +221,12 @@ bool LinuxCoreFunctions::runProgramAsAdmin( const QString& program, const QStrin
 	if( desktop == QLatin1String("KDE") &&
 			QStandardPaths::findExecutable( QStringLiteral("kdesudo") ).isEmpty() == false )
 	{
-		return QProcess::execute( QStringLiteral("kdesudo"), commandLine ) == 0;
+		return QProcess::execute( QStringLiteral("kdesudo"), QStringList( QStringLiteral("--") ) + commandLine ) == 0;
 	}
 
 	if( QStandardPaths::findExecutable( QStringLiteral("gksudo") ).isEmpty() == false )
 	{
-		return QProcess::execute( QStringLiteral("gksudo"), commandLine ) == 0;
+		return QProcess::execute( QStringLiteral("gksudo"), QStringList( QStringLiteral("--") ) + commandLine ) == 0;
 	}
 
 	return QProcess::execute( QStringLiteral("pkexec"), commandLine ) == 0;
@@ -345,3 +345,28 @@ LinuxCoreFunctions::DBusInterfacePointer LinuxCoreFunctions::consoleKitManager()
 										 QStringLiteral("org.freedesktop.ConsoleKit.Manager"),
 										 QDBusConnection::systemBus() );
 }
+
+
+
+int LinuxCoreFunctions::systemctl( const QStringList& arguments )
+{
+	return QProcess::execute( QStringLiteral("systemctl"),
+							  QStringList( { QStringLiteral("--no-pager"), QStringLiteral("-q") } ) + arguments );
+}
+
+
+
+void LinuxCoreFunctions::restartDisplayManagers()
+{
+	for( const auto& displayManager : {
+		 QStringLiteral("gdm"),
+		 QStringLiteral("lightdm"),
+		 QStringLiteral("lxdm"),
+		 QStringLiteral("nodm"),
+		 QStringLiteral("sddm"),
+		 QStringLiteral("wdm"),
+		 QStringLiteral("xdm") } )
+	{
+		systemctl( { QStringLiteral("restart"), displayManager } );
+	}
+}
