@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2018-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -62,17 +62,17 @@ QString LinuxFilesystemFunctions::fileOwnerGroup( const QString& filePath )
 
 bool LinuxFilesystemFunctions::setFileOwnerGroup( const QString& filePath, const QString& ownerGroup )
 {
-	struct stat statBuffer;
+	struct stat statBuffer{};
 	if( stat( filePath.toUtf8().constData(), &statBuffer ) != 0 )
 	{
-		qCritical() << Q_FUNC_INFO << "failed to stat file" << filePath;
+		vCritical() << "failed to stat file" << filePath;
 		return false;
 	}
 
 	const auto grp = getgrnam( ownerGroup.toUtf8().constData() );
 	if( grp == nullptr )
 	{
-		qCritical() << Q_FUNC_INFO << "failed to get gid for" << ownerGroup;
+		vCritical() << "failed to get gid for" << ownerGroup;
 		return false;
 	}
 
@@ -80,7 +80,7 @@ bool LinuxFilesystemFunctions::setFileOwnerGroup( const QString& filePath, const
 
 	if( chown( filePath.toUtf8().constData(), statBuffer.st_uid, gid ) != 0 ) // Flawfinder:ignore
 	{
-		qCritical() << Q_FUNC_INFO << "failed to change owner group of file" << filePath;
+		vCritical() << "failed to change owner group of file" << filePath;
 		return false;
 	}
 
