@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2018-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef LINUX_FILESYSTEM_FUNCTIONS_H
-#define LINUX_FILESYSTEM_FUNCTIONS_H
+#pragma once
 
 #include "PlatformFilesystemFunctions.h"
 
@@ -41,5 +40,3 @@ public:
 	bool setFileOwnerGroupPermissions( const QString& filePath, QFile::Permissions permissions ) override;
 
 };
-
-#endif // LINUX_FILESYSTEM_FUNCTIONS_H
