@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2018-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef LINUX_KEYBOARD_SHORTCUT_TRAPPER_H
-#define LINUX_KEYBOARD_SHORTCUT_TRAPPER_H
+#pragma once
 
 #include "KeyboardShortcutTrapper.h"
 
@@ -31,14 +30,12 @@ class LinuxKeyboardShortcutTrapper : public KeyboardShortcutTrapper
 {
 	Q_OBJECT
 public:
-	LinuxKeyboardShortcutTrapper( QObject* parent = nullptr ) :
+	explicit LinuxKeyboardShortcutTrapper( QObject* parent = nullptr ) :
 	    KeyboardShortcutTrapper( parent )
 	{
 	}
 
-	~LinuxKeyboardShortcutTrapper() override
-	{
-	}
+	~LinuxKeyboardShortcutTrapper() override = default;
 
 	void setEnabled( bool on ) override
 	{
@@ -46,5 +43,3 @@ public:
 	}
 
 } ;
-
-#endif
