@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -23,7 +23,8 @@
  */
 
 #include "LinuxPlatformPlugin.h"
-
+#include "LinuxPlatformConfiguration.h"
+#include "LinuxPlatformConfigurationPage.h"
 
 LinuxPlatformPlugin::LinuxPlatformPlugin( QObject* parent ) :
 	QObject( parent ),
@@ -42,4 +43,15 @@ LinuxPlatformPlugin::LinuxPlatformPlugin( QObject* parent ) :
 
 LinuxPlatformPlugin::~LinuxPlatformPlugin()
 {
+	m_linuxInputDeviceFunctions.enableInputDevices();
 }
+
+
+
+ConfigurationPage* LinuxPlatformPlugin::createConfigurationPage()
+{
+	return new LinuxPlatformConfigurationPage();
+}
+
+
+IMPLEMENT_CONFIG_PROXY(LinuxPlatformConfiguration)
