@@ -38,7 +38,8 @@
 
 LinuxServiceCore::LinuxServiceCore( QObject* parent ) :
 	QObject( parent ),
-	m_loginManager( LinuxCoreFunctions::systemdLoginManager() )
+	m_loginManager( LinuxCoreFunctions::systemdLoginManager() ),
+	m_dataManager()
 {
 	connectToLoginManager();
 }
@@ -131,6 +132,9 @@ void LinuxServiceCore::startServer( const QString& login1SessionId, const QDBusO
 		sessionEnvironment.insert( VeyonCore::sessionIdEnvironmentVariable(), QString::number( sessionId ) );
 	}
 
+	sessionEnvironment.insert( QLatin1String( ServiceDataManager::serviceDataTokenEnvironmentVariable() ),
+							   QString::fromUtf8( m_dataManager.token().toByteArray() ) );
+
 	auto process = new QProcess( this );
 	process->setProcessEnvironment( sessionEnvironment );
 	process->start( VeyonCore::filesystem().serverFilePath() );
