@@ -28,10 +28,15 @@
 
 #include "LinuxCoreFunctions.h"
 #include "LinuxDesktopIntegration.h"
+#include "LinuxKeyboardInput.h"
 #include "LinuxPlatformConfiguration.h"
 #include "LinuxUserFunctions.h"
 #include "VeyonConfiguration.h"
 
+#define XK_MISCELLANY
+
+#include <X11/keysymdef.h>
+
 #include <pwd.h>
 #include <unistd.h>
 
@@ -61,7 +66,7 @@ QString LinuxUserFunctions::fullName( const QString& username )
 
 QStringList LinuxUserFunctions::userGroups( bool queryDomainGroups )
 {
-	Q_UNUSED(queryDomainGroups);
+	Q_UNUSED(queryDomainGroups)
 
 	QStringList groupList;
 
@@ -167,7 +172,7 @@ QStringList LinuxUserFunctions::userGroups( bool queryDomainGroups )
 
 QStringList LinuxUserFunctions::groupsOfUser( const QString& username, bool queryDomainGroups )
 {
-	Q_UNUSED(queryDomainGroups);
+	Q_UNUSED(queryDomainGroups)
 
 	QStringList groupList;
 
@@ -266,12 +271,29 @@ QString LinuxUserFunctions::currentUser()
 
 
 
-void LinuxUserFunctions::logon( const QString& username, const QString& password )
+bool LinuxUserFunctions::prepareLogon( const QString& username, const Password& password )
 {
-	Q_UNUSED(username);
-	Q_UNUSED(password);
+	if( m_logonHelper.prepare( username, password ) )
+	{
+		LinuxCoreFunctions::restartDisplayManagers();
+		return true;
+	}
 
-	// TODO
+	return false;
+}
+
+
+
+bool LinuxUserFunctions::performLogon( const QString& username, const Password& password )
+{
+	LinuxKeyboardInput input;
+
+	input.sendString( username );
+	input.pressAndReleaseKey( XK_Tab );
+	input.sendString( QString::fromUtf8( password.toByteArray() ) );
+	input.pressAndReleaseKey( XK_Return );
+
+	return true;
 }
 
 
@@ -306,7 +328,7 @@ void LinuxUserFunctions::logoff()
 
 
 
-bool LinuxUserFunctions::authenticate( const QString& username, const QString& password )
+bool LinuxUserFunctions::authenticate( const QString& username, const Password& password )
 {
 	QProcess p;
 	p.start( QStringLiteral( "veyon-auth-helper" ), QProcess::ReadWrite | QProcess::Unbuffered );
@@ -319,9 +341,9 @@ bool LinuxUserFunctions::authenticate( const QString& username, const QString& p
 	const auto pamService = LinuxPlatformConfiguration( &VeyonCore::config() ).pamServiceName();
 
 	QDataStream ds( &p );
-	ds << VeyonCore::stripDomain( username );
-	ds << password;
-	ds << pamService;
+	ds << VeyonCore::stripDomain( username ).toUtf8();
+	ds << password.toByteArray();
+	ds << pamService.toUtf8();
 
 	p.waitForFinished( AuthHelperTimeout );
 
