@@ -24,6 +24,7 @@
 
 #pragma once
 
+#include "LogonHelper.h"
 #include "PlatformUserFunctions.h"
 
 #include <pwd.h>
@@ -41,10 +42,11 @@ public:
 	bool isAnyUserLoggedOn() override;
 	QString currentUser() override;
 
-	void logon( const QString& username, const QString& password ) override;
+	bool prepareLogon( const QString& username, const Password& password ) override;
+	bool performLogon( const QString& username, const Password& password ) override;
 	void logoff() override;
 
-	bool authenticate( const QString& username, const QString& password ) override;
+	bool authenticate( const QString& username, const Password& password ) override;
 
 	static uid_t userIdFromName( const QString& username );
 
@@ -52,4 +54,6 @@ private:
 	static constexpr auto WhoProcessTimeout = 3000;
 	static constexpr auto AuthHelperTimeout = 10000;
 
+	LogonHelper m_logonHelper{};
+
 };
