@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef SCREEN_LOCK_FEATURE_PLUGIN_H
-#define SCREEN_LOCK_FEATURE_PLUGIN_H
+#pragma once
 
 #include "FeatureProviderInterface.h"
 
@@ -32,10 +31,10 @@ class LockWidget;
 class ScreenLockFeaturePlugin : public QObject, FeatureProviderInterface, PluginInterface
 {
 	Q_OBJECT
-	Q_PLUGIN_METADATA(IID "io.veyon.Veyon.Plugins.PluginFeatureInterface")
+	Q_PLUGIN_METADATA(IID "io.veyon.Veyon.Plugins.ScreenLock")
 	Q_INTERFACES(PluginInterface FeatureProviderInterface)
 public:
-	ScreenLockFeaturePlugin( QObject* parent = nullptr );
+	explicit ScreenLockFeaturePlugin( QObject* parent = nullptr );
 	~ScreenLockFeaturePlugin() override;
 
 	Plugin::Uid uid() const override
@@ -82,7 +81,9 @@ public:
 	bool handleFeatureMessage( VeyonMasterInterface& master, const FeatureMessage& message,
 							   ComputerControlInterface::Pointer computerControlInterface ) override;
 
-	bool handleFeatureMessage( VeyonServerInterface& server, const FeatureMessage& message ) override;
+	bool handleFeatureMessage( VeyonServerInterface& server,
+							   const MessageContext& messageContext,
+							   const FeatureMessage& message ) override;
 
 	bool handleFeatureMessage( VeyonWorkerInterface& worker, const FeatureMessage& message ) override;
 
@@ -100,5 +101,3 @@ private:
 	LockWidget* m_lockWidget;
 
 };
-
-#endif // SCREEN_LOCK_FEATURE_PLUGIN_H
