@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -32,10 +32,11 @@
 
 ScreenshotFeaturePlugin::ScreenshotFeaturePlugin( QObject* parent ) :
 	QObject( parent ),
-	m_screenshotFeature( Feature( Feature::Action | Feature::Master,
+	m_screenshotFeature( Feature( QStringLiteral( "Screenshot" ),
+								  Feature::Action | Feature::Master,
 								  Feature::Uid( "d5ee3aac-2a87-4d05-b827-0c20344490bd" ),
 								  Feature::Uid(),
-								  tr( "Screenshot" ), QString(),
+								  tr( "Screenshot" ), {},
 								  tr( "Use this function to take a screenshot of selected computers." ),
 								  QStringLiteral(":/screenshot/camera-photo.png") ) ),
 	m_features( { m_screenshotFeature } )
