@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef TEXT_MESSAGE_DIALOG_H
-#define TEXT_MESSAGE_DIALOG_H
+#pragma once
 
 #include <QDialog>
 
@@ -48,5 +47,3 @@ private:
 	QString &m_msgStr;
 
 } ;
-
-#endif
