@@ -47,7 +47,7 @@ void ExternalVncServer::upgrade( const QVersionNumber& oldVersion )
 		if( rawPassword.size() < MaximumPlaintextPasswordLength )
 		{
 			// setting it again will encrypt it
-			m_configuration.setPassword( Configuration::Password::fromPlainText( rawPassword ) );
+			m_configuration.setPassword( Configuration::Password::fromPlainText( rawPassword.toUtf8() ) );
 		}
 	}
 }
@@ -67,7 +67,7 @@ void ExternalVncServer::prepareServer()
 
 
 
-void ExternalVncServer::runServer( int serverPort, const QString& password )
+void ExternalVncServer::runServer( int serverPort, const Password& password )
 {
 	Q_UNUSED(serverPort);
 	Q_UNUSED(password);
@@ -84,7 +84,7 @@ int ExternalVncServer::configuredServerPort()
 
 
 
-QString ExternalVncServer::configuredPassword()
+ExternalVncServer::Password ExternalVncServer::configuredPassword()
 {
 	return m_configuration.password().plainText();
 }
