@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef EXTERNAL_VNC_SERVER_CONFIGURATION_WIDGET_H
-#define EXTERNAL_VNC_SERVER_CONFIGURATION_WIDGET_H
+#pragma once
 
 #include <QWidget>
 
@@ -38,7 +37,7 @@ class ExternalVncServerConfigurationWidget : public QWidget
 	Q_OBJECT
 
 public:
-	ExternalVncServerConfigurationWidget( ExternalVncServerConfiguration& configuration, QWidget* parent = nullptr );
+	explicit ExternalVncServerConfigurationWidget( ExternalVncServerConfiguration& configuration, QWidget* parent = nullptr );
 	~ExternalVncServerConfigurationWidget() override;
 
 private:
@@ -46,5 +45,3 @@ private:
 	ExternalVncServerConfiguration& m_configuration;
 
 };
-
-#endif // EXTERNAL_VNC_SERVER_CONFIGURATION_WIDGET_H
