@@ -77,14 +77,14 @@ public:
 
 	void prepareServer() override;
 
-	void runServer( int serverPort, const QString& password ) override;
+	void runServer( int serverPort, const Password& password ) override;
 
 	int configuredServerPort() override
 	{
 		return -1;
 	}
 
-	QString configuredPassword() override
+	Password configuredPassword() override
 	{
 		return {};
 	}
@@ -99,7 +99,7 @@ public:
 		return m_serverPort;
 	}
 
-	const QString& password() const
+	const Password& password() const
 	{
 		return m_password;
 	}
@@ -110,7 +110,7 @@ private:
 	static constexpr auto DefaultServerPort = 5900;
 
 	int m_serverPort;
-	QString m_password;
+	Password m_password;
 
 	LogoffEventFilter* m_logoffEventFilter;
 
