@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef ULTRAVNC_CONFIGURATION_WIDGET_H
-#define ULTRAVNC_CONFIGURATION_WIDGET_H
+#pragma once
 
 #include <QWidget>
 
@@ -39,12 +38,10 @@ class UltraVncConfigurationWidget : public QWidget
 
 public:
 	UltraVncConfigurationWidget( UltraVncConfiguration& configuration );
-	~UltraVncConfigurationWidget();
+	~UltraVncConfigurationWidget() override;
 
 private:
 	Ui::UltraVncConfigurationWidget *ui;
 	UltraVncConfiguration& m_configuration;
 
 };
-
-#endif // ULTRAVNC_CONFIGURATION_WIDGET_H
