@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef SERVER_ACCESS_CONTROL_MANAGER_H
-#define SERVER_ACCESS_CONTROL_MANAGER_H
+#pragma once
 
 #include "DesktopAccessDialog.h"
 #include "RfbVeyonAuth.h"
@@ -44,12 +43,10 @@ public:
 
 
 signals:
-	void accessControlError( const QString& host, const QString& user );
+	void finished( VncServerClient* client );
 
 private:
-	enum {
-		ClientWaitInterval = 1000
-	};
+	static constexpr int ClientWaitInterval = 1000;
 
 	void performAccessControl( VncServerClient* client );
 	VncServerClient::AccessControlState confirmDesktopAccess( VncServerClient* client );
@@ -62,11 +59,9 @@ private:
 
 	VncServerClientList m_clients;
 
-	typedef QPair<QString, QString> HostUserPair;
-	typedef QMap<HostUserPair, DesktopAccessDialog::Choice> DesktopAccessChoiceMap;
+	using HostUserPair = QPair<QString, QString>;
+	using DesktopAccessChoiceMap = QMap<HostUserPair, DesktopAccessDialog::Choice>;
 
 	DesktopAccessChoiceMap m_desktopAccessChoices;
 
 } ;
-
-#endif
