@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2018-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,10 +22,8 @@
  *
  */
 
-#ifndef VEYON_WORKER_H
-#define VEYON_WORKER_H
+#pragma once
 
-#include "BuiltinFeatures.h"
 #include "FeatureManager.h"
 #include "VeyonWorkerInterface.h"
 
@@ -35,14 +33,18 @@ class VeyonWorker : public QObject, VeyonWorkerInterface
 {
 	Q_OBJECT
 public:
-	VeyonWorker( const QString& featureUid, QObject* parent = nullptr );
+	explicit VeyonWorker( const QString& featureUid, QObject* parent = nullptr );
+
+	bool sendFeatureMessageReply( const FeatureMessage& reply ) override;
+
+	VeyonCore& core()
+	{
+		return m_core;
+	}
 
 private:
 	VeyonCore m_core;
-	BuiltinFeatures m_builtinFeatures;
 	FeatureManager m_featureManager;
 	FeatureWorkerManagerConnection* m_workerManagerConnection;
 
 } ;
-
-#endif
