@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -30,7 +30,7 @@
 int main( int argc, char **argv )
 {
 	QApplication app( argc, argv );
-	app.setWindowIcon( QIcon( QStringLiteral(":/resources/icon64.png") ) );
+	app.setWindowIcon( QIcon( QStringLiteral(":/core/icon64.png") ) );
 
 	const auto arguments = app.arguments();
 
@@ -47,5 +47,5 @@ int main( int argc, char **argv )
 
 	VeyonWorker worker( featureUid );
 
-	return app.exec();
+	return worker.core().exec();
 }
